# coding: utf-8
import pprint
import six
from enum import Enum



class Transaction:

    swagger_types = {
    
        'accept_header': 'str',
        'accept_language_header': 'str',
        'allowed_payment_method_brands': 'list[int]',
        'allowed_payment_method_configurations': 'list[int]',
        'authorization_amount': 'float',
        'authorization_environment': 'ChargeAttemptEnvironment',
        'authorization_sales_channel': 'int',
        'authorization_timeout_on': 'datetime',
        'authorized_on': 'datetime',
        'auto_confirmation_enabled': 'bool',
        'billing_address': 'Address',
        'charge_retry_enabled': 'bool',
        'completed_amount': 'float',
        'completed_on': 'datetime',
        'completion_behavior': 'TransactionCompletionBehavior',
        'completion_timeout_on': 'datetime',
        'confirmed_by': 'int',
        'confirmed_on': 'datetime',
        'created_by': 'int',
        'created_on': 'datetime',
        'currency': 'str',
        'customer_email_address': 'str',
        'customer_id': 'str',
        'customers_presence': 'CustomersPresence',
        'delivery_decision_made_on': 'datetime',
        'device_session_identifier': 'str',
        'emails_disabled': 'bool',
        'end_of_life': 'datetime',
        'environment': 'Environment',
        'environment_selection_strategy': 'TransactionEnvironmentSelectionStrategy',
        'failed_on': 'datetime',
        'failed_url': 'str',
        'failure_reason': 'FailureReason',
        'group': 'TransactionGroup',
        'id': 'int',
        'internet_protocol_address': 'str',
        'internet_protocol_address_country': 'str',
        'invoice_merchant_reference': 'str',
        'java_enabled': 'bool',
        'language': 'str',
        'line_items': 'list[LineItem]',
        'linked_space_id': 'int',
        'merchant_reference': 'str',
        'meta_data': 'dict(str, str)',
        'parent': 'int',
        'payment_connector_configuration': 'PaymentConnectorConfiguration',
        'planned_purge_date': 'datetime',
        'processing_on': 'datetime',
        'refunded_amount': 'float',
        'screen_color_depth': 'str',
        'screen_height': 'str',
        'screen_width': 'str',
        'shipping_address': 'Address',
        'shipping_method': 'str',
        'space_view_id': 'int',
        'state': 'TransactionState',
        'success_url': 'str',
        'terminal': 'PaymentTerminal',
        'time_zone': 'str',
        'token': 'Token',
        'tokenization_mode': 'TokenizationMode',
        'total_applied_fees': 'float',
        'total_settled_amount': 'float',
        'user_agent_header': 'str',
        'user_failure_message': 'str',
        'user_interface_type': 'TransactionUserInterfaceType',
        'version': 'int',
        'window_height': 'str',
        'window_width': 'str',
        'years_to_keep': 'int',
    }

    attribute_map = {
        'accept_header': 'acceptHeader','accept_language_header': 'acceptLanguageHeader','allowed_payment_method_brands': 'allowedPaymentMethodBrands','allowed_payment_method_configurations': 'allowedPaymentMethodConfigurations','authorization_amount': 'authorizationAmount','authorization_environment': 'authorizationEnvironment','authorization_sales_channel': 'authorizationSalesChannel','authorization_timeout_on': 'authorizationTimeoutOn','authorized_on': 'authorizedOn','auto_confirmation_enabled': 'autoConfirmationEnabled','billing_address': 'billingAddress','charge_retry_enabled': 'chargeRetryEnabled','completed_amount': 'completedAmount','completed_on': 'completedOn','completion_behavior': 'completionBehavior','completion_timeout_on': 'completionTimeoutOn','confirmed_by': 'confirmedBy','confirmed_on': 'confirmedOn','created_by': 'createdBy','created_on': 'createdOn','currency': 'currency','customer_email_address': 'customerEmailAddress','customer_id': 'customerId','customers_presence': 'customersPresence','delivery_decision_made_on': 'deliveryDecisionMadeOn','device_session_identifier': 'deviceSessionIdentifier','emails_disabled': 'emailsDisabled','end_of_life': 'endOfLife','environment': 'environment','environment_selection_strategy': 'environmentSelectionStrategy','failed_on': 'failedOn','failed_url': 'failedUrl','failure_reason': 'failureReason','group': 'group','id': 'id','internet_protocol_address': 'internetProtocolAddress','internet_protocol_address_country': 'internetProtocolAddressCountry','invoice_merchant_reference': 'invoiceMerchantReference','java_enabled': 'javaEnabled','language': 'language','line_items': 'lineItems','linked_space_id': 'linkedSpaceId','merchant_reference': 'merchantReference','meta_data': 'metaData','parent': 'parent','payment_connector_configuration': 'paymentConnectorConfiguration','planned_purge_date': 'plannedPurgeDate','processing_on': 'processingOn','refunded_amount': 'refundedAmount','screen_color_depth': 'screenColorDepth','screen_height': 'screenHeight','screen_width': 'screenWidth','shipping_address': 'shippingAddress','shipping_method': 'shippingMethod','space_view_id': 'spaceViewId','state': 'state','success_url': 'successUrl','terminal': 'terminal','time_zone': 'timeZone','token': 'token','tokenization_mode': 'tokenizationMode','total_applied_fees': 'totalAppliedFees','total_settled_amount': 'totalSettledAmount','user_agent_header': 'userAgentHeader','user_failure_message': 'userFailureMessage','user_interface_type': 'userInterfaceType','version': 'version','window_height': 'windowHeight','window_width': 'windowWidth','years_to_keep': 'yearsToKeep',
    }

    
    _accept_header = None
    _accept_language_header = None
    _allowed_payment_method_brands = None
    _allowed_payment_method_configurations = None
    _authorization_amount = None
    _authorization_environment = None
    _authorization_sales_channel = None
    _authorization_timeout_on = None
    _authorized_on = None
    _auto_confirmation_enabled = None
    _billing_address = None
    _charge_retry_enabled = None
    _completed_amount = None
    _completed_on = None
    _completion_behavior = None
    _completion_timeout_on = None
    _confirmed_by = None
    _confirmed_on = None
    _created_by = None
    _created_on = None
    _currency = None
    _customer_email_address = None
    _customer_id = None
    _customers_presence = None
    _delivery_decision_made_on = None
    _device_session_identifier = None
    _emails_disabled = None
    _end_of_life = None
    _environment = None
    _environment_selection_strategy = None
    _failed_on = None
    _failed_url = None
    _failure_reason = None
    _group = None
    _id = None
    _internet_protocol_address = None
    _internet_protocol_address_country = None
    _invoice_merchant_reference = None
    _java_enabled = None
    _language = None
    _line_items = None
    _linked_space_id = None
    _merchant_reference = None
    _meta_data = None
    _parent = None
    _payment_connector_configuration = None
    _planned_purge_date = None
    _processing_on = None
    _refunded_amount = None
    _screen_color_depth = None
    _screen_height = None
    _screen_width = None
    _shipping_address = None
    _shipping_method = None
    _space_view_id = None
    _state = None
    _success_url = None
    _terminal = None
    _time_zone = None
    _token = None
    _tokenization_mode = None
    _total_applied_fees = None
    _total_settled_amount = None
    _user_agent_header = None
    _user_failure_message = None
    _user_interface_type = None
    _version = None
    _window_height = None
    _window_width = None
    _years_to_keep = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.accept_header = kwargs.get('accept_header', None)
        self.accept_language_header = kwargs.get('accept_language_header', None)
        self.allowed_payment_method_brands = kwargs.get('allowed_payment_method_brands', None)
        self.allowed_payment_method_configurations = kwargs.get('allowed_payment_method_configurations', None)
        self.authorization_amount = kwargs.get('authorization_amount', None)
        self.authorization_environment = kwargs.get('authorization_environment', None)
        self.authorization_sales_channel = kwargs.get('authorization_sales_channel', None)
        self.authorization_timeout_on = kwargs.get('authorization_timeout_on', None)
        self.authorized_on = kwargs.get('authorized_on', None)
        self.auto_confirmation_enabled = kwargs.get('auto_confirmation_enabled', None)
        self.billing_address = kwargs.get('billing_address', None)
        self.charge_retry_enabled = kwargs.get('charge_retry_enabled', None)
        self.completed_amount = kwargs.get('completed_amount', None)
        self.completed_on = kwargs.get('completed_on', None)
        self.completion_behavior = kwargs.get('completion_behavior', None)
        self.completion_timeout_on = kwargs.get('completion_timeout_on', None)
        self.confirmed_by = kwargs.get('confirmed_by', None)
        self.confirmed_on = kwargs.get('confirmed_on', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_on = kwargs.get('created_on', None)
        self.currency = kwargs.get('currency', None)
        self.customer_email_address = kwargs.get('customer_email_address', None)
        self.customer_id = kwargs.get('customer_id', None)
        self.customers_presence = kwargs.get('customers_presence', None)
        self.delivery_decision_made_on = kwargs.get('delivery_decision_made_on', None)
        self.device_session_identifier = kwargs.get('device_session_identifier', None)
        self.emails_disabled = kwargs.get('emails_disabled', None)
        self.end_of_life = kwargs.get('end_of_life', None)
        self.environment = kwargs.get('environment', None)
        self.environment_selection_strategy = kwargs.get('environment_selection_strategy', None)
        self.failed_on = kwargs.get('failed_on', None)
        self.failed_url = kwargs.get('failed_url', None)
        self.failure_reason = kwargs.get('failure_reason', None)
        self.group = kwargs.get('group', None)
        self.id = kwargs.get('id', None)
        self.internet_protocol_address = kwargs.get('internet_protocol_address', None)
        self.internet_protocol_address_country = kwargs.get('internet_protocol_address_country', None)
        self.invoice_merchant_reference = kwargs.get('invoice_merchant_reference', None)
        self.java_enabled = kwargs.get('java_enabled', None)
        self.language = kwargs.get('language', None)
        self.line_items = kwargs.get('line_items', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.merchant_reference = kwargs.get('merchant_reference', None)
        self.meta_data = kwargs.get('meta_data', None)
        self.parent = kwargs.get('parent', None)
        self.payment_connector_configuration = kwargs.get('payment_connector_configuration', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.processing_on = kwargs.get('processing_on', None)
        self.refunded_amount = kwargs.get('refunded_amount', None)
        self.screen_color_depth = kwargs.get('screen_color_depth', None)
        self.screen_height = kwargs.get('screen_height', None)
        self.screen_width = kwargs.get('screen_width', None)
        self.shipping_address = kwargs.get('shipping_address', None)
        self.shipping_method = kwargs.get('shipping_method', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        self.state = kwargs.get('state', None)
        self.success_url = kwargs.get('success_url', None)
        self.terminal = kwargs.get('terminal', None)
        self.time_zone = kwargs.get('time_zone', None)
        self.token = kwargs.get('token', None)
        self.tokenization_mode = kwargs.get('tokenization_mode', None)
        self.total_applied_fees = kwargs.get('total_applied_fees', None)
        self.total_settled_amount = kwargs.get('total_settled_amount', None)
        self.user_agent_header = kwargs.get('user_agent_header', None)
        self.user_failure_message = kwargs.get('user_failure_message', None)
        self.user_interface_type = kwargs.get('user_interface_type', None)
        self.version = kwargs.get('version', None)
        self.window_height = kwargs.get('window_height', None)
        self.window_width = kwargs.get('window_width', None)
        self.years_to_keep = kwargs.get('years_to_keep', None)
        

    
    @property
    def accept_header(self):
        """Gets the accept_header of this Transaction.

            The 'Accept' header of the customer's web browser.

        :return: The accept_header of this Transaction.
        :rtype: str
        """
        return self._accept_header

    @accept_header.setter
    def accept_header(self, accept_header):
        """Sets the accept_header of this Transaction.

            The 'Accept' header of the customer's web browser.

        :param accept_header: The accept_header of this Transaction.
        :type: str
        """

        self._accept_header = accept_header
    
    @property
    def accept_language_header(self):
        """Gets the accept_language_header of this Transaction.

            The 'Accept Language' header of the customer's web browser.

        :return: The accept_language_header of this Transaction.
        :rtype: str
        """
        return self._accept_language_header

    @accept_language_header.setter
    def accept_language_header(self, accept_language_header):
        """Sets the accept_language_header of this Transaction.

            The 'Accept Language' header of the customer's web browser.

        :param accept_language_header: The accept_language_header of this Transaction.
        :type: str
        """

        self._accept_language_header = accept_language_header
    
    @property
    def allowed_payment_method_brands(self):
        """Gets the allowed_payment_method_brands of this Transaction.

            The payment method brands that can be used to authorize the transaction.

        :return: The allowed_payment_method_brands of this Transaction.
        :rtype: list[int]
        """
        return self._allowed_payment_method_brands

    @allowed_payment_method_brands.setter
    def allowed_payment_method_brands(self, allowed_payment_method_brands):
        """Sets the allowed_payment_method_brands of this Transaction.

            The payment method brands that can be used to authorize the transaction.

        :param allowed_payment_method_brands: The allowed_payment_method_brands of this Transaction.
        :type: list[int]
        """

        self._allowed_payment_method_brands = allowed_payment_method_brands
    
    @property
    def allowed_payment_method_configurations(self):
        """Gets the allowed_payment_method_configurations of this Transaction.

            The payment method configurations that can be used to authorize the transaction.

        :return: The allowed_payment_method_configurations of this Transaction.
        :rtype: list[int]
        """
        return self._allowed_payment_method_configurations

    @allowed_payment_method_configurations.setter
    def allowed_payment_method_configurations(self, allowed_payment_method_configurations):
        """Sets the allowed_payment_method_configurations of this Transaction.

            The payment method configurations that can be used to authorize the transaction.

        :param allowed_payment_method_configurations: The allowed_payment_method_configurations of this Transaction.
        :type: list[int]
        """

        self._allowed_payment_method_configurations = allowed_payment_method_configurations
    
    @property
    def authorization_amount(self):
        """Gets the authorization_amount of this Transaction.

            The sum of all line item prices including taxes in the transaction's currency.

        :return: The authorization_amount of this Transaction.
        :rtype: float
        """
        return self._authorization_amount

    @authorization_amount.setter
    def authorization_amount(self, authorization_amount):
        """Sets the authorization_amount of this Transaction.

            The sum of all line item prices including taxes in the transaction's currency.

        :param authorization_amount: The authorization_amount of this Transaction.
        :type: float
        """

        self._authorization_amount = authorization_amount
    
    @property
    def authorization_environment(self):
        """Gets the authorization_environment of this Transaction.

            The environment in which the transaction was authorized.

        :return: The authorization_environment of this Transaction.
        :rtype: ChargeAttemptEnvironment
        """
        return self._authorization_environment

    @authorization_environment.setter
    def authorization_environment(self, authorization_environment):
        """Sets the authorization_environment of this Transaction.

            The environment in which the transaction was authorized.

        :param authorization_environment: The authorization_environment of this Transaction.
        :type: ChargeAttemptEnvironment
        """

        self._authorization_environment = authorization_environment
    
    @property
    def authorization_sales_channel(self):
        """Gets the authorization_sales_channel of this Transaction.

            The sales channel through which the transaction was placed.

        :return: The authorization_sales_channel of this Transaction.
        :rtype: int
        """
        return self._authorization_sales_channel

    @authorization_sales_channel.setter
    def authorization_sales_channel(self, authorization_sales_channel):
        """Sets the authorization_sales_channel of this Transaction.

            The sales channel through which the transaction was placed.

        :param authorization_sales_channel: The authorization_sales_channel of this Transaction.
        :type: int
        """

        self._authorization_sales_channel = authorization_sales_channel
    
    @property
    def authorization_timeout_on(self):
        """Gets the authorization_timeout_on of this Transaction.

            The date and time when the transaction must be authorized, otherwise it will canceled.

        :return: The authorization_timeout_on of this Transaction.
        :rtype: datetime
        """
        return self._authorization_timeout_on

    @authorization_timeout_on.setter
    def authorization_timeout_on(self, authorization_timeout_on):
        """Sets the authorization_timeout_on of this Transaction.

            The date and time when the transaction must be authorized, otherwise it will canceled.

        :param authorization_timeout_on: The authorization_timeout_on of this Transaction.
        :type: datetime
        """

        self._authorization_timeout_on = authorization_timeout_on
    
    @property
    def authorized_on(self):
        """Gets the authorized_on of this Transaction.

            The date and time when the transaction was authorized.

        :return: The authorized_on of this Transaction.
        :rtype: datetime
        """
        return self._authorized_on

    @authorized_on.setter
    def authorized_on(self, authorized_on):
        """Sets the authorized_on of this Transaction.

            The date and time when the transaction was authorized.

        :param authorized_on: The authorized_on of this Transaction.
        :type: datetime
        """

        self._authorized_on = authorized_on
    
    @property
    def auto_confirmation_enabled(self):
        """Gets the auto_confirmation_enabled of this Transaction.

            Whether the transaction can be confirmed automatically or whether this must be done explicitly via the API. Default is true.

        :return: The auto_confirmation_enabled of this Transaction.
        :rtype: bool
        """
        return self._auto_confirmation_enabled

    @auto_confirmation_enabled.setter
    def auto_confirmation_enabled(self, auto_confirmation_enabled):
        """Sets the auto_confirmation_enabled of this Transaction.

            Whether the transaction can be confirmed automatically or whether this must be done explicitly via the API. Default is true.

        :param auto_confirmation_enabled: The auto_confirmation_enabled of this Transaction.
        :type: bool
        """

        self._auto_confirmation_enabled = auto_confirmation_enabled
    
    @property
    def billing_address(self):
        """Gets the billing_address of this Transaction.

            The address associated with the payment method for invoicing and transaction processing purposes.

        :return: The billing_address of this Transaction.
        :rtype: Address
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this Transaction.

            The address associated with the payment method for invoicing and transaction processing purposes.

        :param billing_address: The billing_address of this Transaction.
        :type: Address
        """

        self._billing_address = billing_address
    
    @property
    def charge_retry_enabled(self):
        """Gets the charge_retry_enabled of this Transaction.

            Whether the customer can make further payment attempts if the first one has failed. Default is true.

        :return: The charge_retry_enabled of this Transaction.
        :rtype: bool
        """
        return self._charge_retry_enabled

    @charge_retry_enabled.setter
    def charge_retry_enabled(self, charge_retry_enabled):
        """Sets the charge_retry_enabled of this Transaction.

            Whether the customer can make further payment attempts if the first one has failed. Default is true.

        :param charge_retry_enabled: The charge_retry_enabled of this Transaction.
        :type: bool
        """

        self._charge_retry_enabled = charge_retry_enabled
    
    @property
    def completed_amount(self):
        """Gets the completed_amount of this Transaction.

            The total amount that was completed, in the transaction's currency.

        :return: The completed_amount of this Transaction.
        :rtype: float
        """
        return self._completed_amount

    @completed_amount.setter
    def completed_amount(self, completed_amount):
        """Sets the completed_amount of this Transaction.

            The total amount that was completed, in the transaction's currency.

        :param completed_amount: The completed_amount of this Transaction.
        :type: float
        """

        self._completed_amount = completed_amount
    
    @property
    def completed_on(self):
        """Gets the completed_on of this Transaction.

            The date and time when the transaction was completed.

        :return: The completed_on of this Transaction.
        :rtype: datetime
        """
        return self._completed_on

    @completed_on.setter
    def completed_on(self, completed_on):
        """Sets the completed_on of this Transaction.

            The date and time when the transaction was completed.

        :param completed_on: The completed_on of this Transaction.
        :type: datetime
        """

        self._completed_on = completed_on
    
    @property
    def completion_behavior(self):
        """Gets the completion_behavior of this Transaction.

            The behavior that controls when the transaction is completed.

        :return: The completion_behavior of this Transaction.
        :rtype: TransactionCompletionBehavior
        """
        return self._completion_behavior

    @completion_behavior.setter
    def completion_behavior(self, completion_behavior):
        """Sets the completion_behavior of this Transaction.

            The behavior that controls when the transaction is completed.

        :param completion_behavior: The completion_behavior of this Transaction.
        :type: TransactionCompletionBehavior
        """

        self._completion_behavior = completion_behavior
    
    @property
    def completion_timeout_on(self):
        """Gets the completion_timeout_on of this Transaction.

            The date and time when the transaction is completed automatically.

        :return: The completion_timeout_on of this Transaction.
        :rtype: datetime
        """
        return self._completion_timeout_on

    @completion_timeout_on.setter
    def completion_timeout_on(self, completion_timeout_on):
        """Sets the completion_timeout_on of this Transaction.

            The date and time when the transaction is completed automatically.

        :param completion_timeout_on: The completion_timeout_on of this Transaction.
        :type: datetime
        """

        self._completion_timeout_on = completion_timeout_on
    
    @property
    def confirmed_by(self):
        """Gets the confirmed_by of this Transaction.

            The ID of the user the transaction was confirmed by.

        :return: The confirmed_by of this Transaction.
        :rtype: int
        """
        return self._confirmed_by

    @confirmed_by.setter
    def confirmed_by(self, confirmed_by):
        """Sets the confirmed_by of this Transaction.

            The ID of the user the transaction was confirmed by.

        :param confirmed_by: The confirmed_by of this Transaction.
        :type: int
        """

        self._confirmed_by = confirmed_by
    
    @property
    def confirmed_on(self):
        """Gets the confirmed_on of this Transaction.

            The date and time when the transaction was created.

        :return: The confirmed_on of this Transaction.
        :rtype: datetime
        """
        return self._confirmed_on

    @confirmed_on.setter
    def confirmed_on(self, confirmed_on):
        """Sets the confirmed_on of this Transaction.

            The date and time when the transaction was created.

        :param confirmed_on: The confirmed_on of this Transaction.
        :type: datetime
        """

        self._confirmed_on = confirmed_on
    
    @property
    def created_by(self):
        """Gets the created_by of this Transaction.

            The ID of the user the transaction was created by.

        :return: The created_by of this Transaction.
        :rtype: int
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Transaction.

            The ID of the user the transaction was created by.

        :param created_by: The created_by of this Transaction.
        :type: int
        """

        self._created_by = created_by
    
    @property
    def created_on(self):
        """Gets the created_on of this Transaction.

            The date and time when the object was created.

        :return: The created_on of this Transaction.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this Transaction.

            The date and time when the object was created.

        :param created_on: The created_on of this Transaction.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def currency(self):
        """Gets the currency of this Transaction.

            The three-letter code (ISO 4217 format) of the transaction's currency.

        :return: The currency of this Transaction.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Transaction.

            The three-letter code (ISO 4217 format) of the transaction's currency.

        :param currency: The currency of this Transaction.
        :type: str
        """

        self._currency = currency
    
    @property
    def customer_email_address(self):
        """Gets the customer_email_address of this Transaction.

            The customer's email address.

        :return: The customer_email_address of this Transaction.
        :rtype: str
        """
        return self._customer_email_address

    @customer_email_address.setter
    def customer_email_address(self, customer_email_address):
        """Sets the customer_email_address of this Transaction.

            The customer's email address.

        :param customer_email_address: The customer_email_address of this Transaction.
        :type: str
        """
        if customer_email_address is not None and len(customer_email_address) > 254:
            raise ValueError("Invalid value for `customer_email_address`, length must be less than or equal to `254`")

        self._customer_email_address = customer_email_address
    
    @property
    def customer_id(self):
        """Gets the customer_id of this Transaction.

            The unique identifier of the customer in the external system.

        :return: The customer_id of this Transaction.
        :rtype: str
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this Transaction.

            The unique identifier of the customer in the external system.

        :param customer_id: The customer_id of this Transaction.
        :type: str
        """

        self._customer_id = customer_id
    
    @property
    def customers_presence(self):
        """Gets the customers_presence of this Transaction.

            The customer's presence indicates whether and in what way the transaction's customer is present. Default is VIRTUAL_PRESENT.

        :return: The customers_presence of this Transaction.
        :rtype: CustomersPresence
        """
        return self._customers_presence

    @customers_presence.setter
    def customers_presence(self, customers_presence):
        """Sets the customers_presence of this Transaction.

            The customer's presence indicates whether and in what way the transaction's customer is present. Default is VIRTUAL_PRESENT.

        :param customers_presence: The customers_presence of this Transaction.
        :type: CustomersPresence
        """

        self._customers_presence = customers_presence
    
    @property
    def delivery_decision_made_on(self):
        """Gets the delivery_decision_made_on of this Transaction.

            This date and time when the decision was made as to whether the order should be shipped.

        :return: The delivery_decision_made_on of this Transaction.
        :rtype: datetime
        """
        return self._delivery_decision_made_on

    @delivery_decision_made_on.setter
    def delivery_decision_made_on(self, delivery_decision_made_on):
        """Sets the delivery_decision_made_on of this Transaction.

            This date and time when the decision was made as to whether the order should be shipped.

        :param delivery_decision_made_on: The delivery_decision_made_on of this Transaction.
        :type: datetime
        """

        self._delivery_decision_made_on = delivery_decision_made_on
    
    @property
    def device_session_identifier(self):
        """Gets the device_session_identifier of this Transaction.

            Allows to link the transaction to the data collected from the customer's device.

        :return: The device_session_identifier of this Transaction.
        :rtype: str
        """
        return self._device_session_identifier

    @device_session_identifier.setter
    def device_session_identifier(self, device_session_identifier):
        """Sets the device_session_identifier of this Transaction.

            Allows to link the transaction to the data collected from the customer's device.

        :param device_session_identifier: The device_session_identifier of this Transaction.
        :type: str
        """
        if device_session_identifier is not None and len(device_session_identifier) > 40:
            raise ValueError("Invalid value for `device_session_identifier`, length must be less than or equal to `40`")
        if device_session_identifier is not None and len(device_session_identifier) < 10:
            raise ValueError("Invalid value for `device_session_identifier`, length must be greater than or equal to `10`")

        self._device_session_identifier = device_session_identifier
    
    @property
    def emails_disabled(self):
        """Gets the emails_disabled of this Transaction.

            Whether email sending is deactivated for the transaction. Default is false.

        :return: The emails_disabled of this Transaction.
        :rtype: bool
        """
        return self._emails_disabled

    @emails_disabled.setter
    def emails_disabled(self, emails_disabled):
        """Sets the emails_disabled of this Transaction.

            Whether email sending is deactivated for the transaction. Default is false.

        :param emails_disabled: The emails_disabled of this Transaction.
        :type: bool
        """

        self._emails_disabled = emails_disabled
    
    @property
    def end_of_life(self):
        """Gets the end_of_life of this Transaction.

            The date and time when the transaction reaches its end of live. No further actions can be carried out at this time.

        :return: The end_of_life of this Transaction.
        :rtype: datetime
        """
        return self._end_of_life

    @end_of_life.setter
    def end_of_life(self, end_of_life):
        """Sets the end_of_life of this Transaction.

            The date and time when the transaction reaches its end of live. No further actions can be carried out at this time.

        :param end_of_life: The end_of_life of this Transaction.
        :type: datetime
        """

        self._end_of_life = end_of_life
    
    @property
    def environment(self):
        """Gets the environment of this Transaction.

            The environment used when rendering resources.

        :return: The environment of this Transaction.
        :rtype: Environment
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this Transaction.

            The environment used when rendering resources.

        :param environment: The environment of this Transaction.
        :type: Environment
        """

        self._environment = environment
    
    @property
    def environment_selection_strategy(self):
        """Gets the environment_selection_strategy of this Transaction.

            The strategy for determining whether the transaction is to be processed in the test or production environment.

        :return: The environment_selection_strategy of this Transaction.
        :rtype: TransactionEnvironmentSelectionStrategy
        """
        return self._environment_selection_strategy

    @environment_selection_strategy.setter
    def environment_selection_strategy(self, environment_selection_strategy):
        """Sets the environment_selection_strategy of this Transaction.

            The strategy for determining whether the transaction is to be processed in the test or production environment.

        :param environment_selection_strategy: The environment_selection_strategy of this Transaction.
        :type: TransactionEnvironmentSelectionStrategy
        """

        self._environment_selection_strategy = environment_selection_strategy
    
    @property
    def failed_on(self):
        """Gets the failed_on of this Transaction.

            The date and time when the transaction failed.

        :return: The failed_on of this Transaction.
        :rtype: datetime
        """
        return self._failed_on

    @failed_on.setter
    def failed_on(self, failed_on):
        """Sets the failed_on of this Transaction.

            The date and time when the transaction failed.

        :param failed_on: The failed_on of this Transaction.
        :type: datetime
        """

        self._failed_on = failed_on
    
    @property
    def failed_url(self):
        """Gets the failed_url of this Transaction.

            The URL to redirect the customer back to after they canceled or failed to authenticated their payment.

        :return: The failed_url of this Transaction.
        :rtype: str
        """
        return self._failed_url

    @failed_url.setter
    def failed_url(self, failed_url):
        """Sets the failed_url of this Transaction.

            The URL to redirect the customer back to after they canceled or failed to authenticated their payment.

        :param failed_url: The failed_url of this Transaction.
        :type: str
        """
        if failed_url is not None and len(failed_url) > 2000:
            raise ValueError("Invalid value for `failed_url`, length must be less than or equal to `2000`")
        if failed_url is not None and len(failed_url) < 9:
            raise ValueError("Invalid value for `failed_url`, length must be greater than or equal to `9`")

        self._failed_url = failed_url
    
    @property
    def failure_reason(self):
        """Gets the failure_reason of this Transaction.

            The reason for the failure of the transaction.

        :return: The failure_reason of this Transaction.
        :rtype: FailureReason
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """Sets the failure_reason of this Transaction.

            The reason for the failure of the transaction.

        :param failure_reason: The failure_reason of this Transaction.
        :type: FailureReason
        """

        self._failure_reason = failure_reason
    
    @property
    def group(self):
        """Gets the group of this Transaction.

            The group that the transaction belongs to.

        :return: The group of this Transaction.
        :rtype: TransactionGroup
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this Transaction.

            The group that the transaction belongs to.

        :param group: The group of this Transaction.
        :type: TransactionGroup
        """

        self._group = group
    
    @property
    def id(self):
        """Gets the id of this Transaction.

            A unique identifier for the object.

        :return: The id of this Transaction.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Transaction.

            A unique identifier for the object.

        :param id: The id of this Transaction.
        :type: int
        """

        self._id = id
    
    @property
    def internet_protocol_address(self):
        """Gets the internet_protocol_address of this Transaction.

            The IP address of the customer's device.

        :return: The internet_protocol_address of this Transaction.
        :rtype: str
        """
        return self._internet_protocol_address

    @internet_protocol_address.setter
    def internet_protocol_address(self, internet_protocol_address):
        """Sets the internet_protocol_address of this Transaction.

            The IP address of the customer's device.

        :param internet_protocol_address: The internet_protocol_address of this Transaction.
        :type: str
        """

        self._internet_protocol_address = internet_protocol_address
    
    @property
    def internet_protocol_address_country(self):
        """Gets the internet_protocol_address_country of this Transaction.

            The country determined from the IP address of the customer's device.

        :return: The internet_protocol_address_country of this Transaction.
        :rtype: str
        """
        return self._internet_protocol_address_country

    @internet_protocol_address_country.setter
    def internet_protocol_address_country(self, internet_protocol_address_country):
        """Sets the internet_protocol_address_country of this Transaction.

            The country determined from the IP address of the customer's device.

        :param internet_protocol_address_country: The internet_protocol_address_country of this Transaction.
        :type: str
        """

        self._internet_protocol_address_country = internet_protocol_address_country
    
    @property
    def invoice_merchant_reference(self):
        """Gets the invoice_merchant_reference of this Transaction.

            The merchant's reference used to identify the invoice.

        :return: The invoice_merchant_reference of this Transaction.
        :rtype: str
        """
        return self._invoice_merchant_reference

    @invoice_merchant_reference.setter
    def invoice_merchant_reference(self, invoice_merchant_reference):
        """Sets the invoice_merchant_reference of this Transaction.

            The merchant's reference used to identify the invoice.

        :param invoice_merchant_reference: The invoice_merchant_reference of this Transaction.
        :type: str
        """
        if invoice_merchant_reference is not None and len(invoice_merchant_reference) > 100:
            raise ValueError("Invalid value for `invoice_merchant_reference`, length must be less than or equal to `100`")

        self._invoice_merchant_reference = invoice_merchant_reference
    
    @property
    def java_enabled(self):
        """Gets the java_enabled of this Transaction.

            Whether Java is enabled on the customer's web browser.

        :return: The java_enabled of this Transaction.
        :rtype: bool
        """
        return self._java_enabled

    @java_enabled.setter
    def java_enabled(self, java_enabled):
        """Sets the java_enabled of this Transaction.

            Whether Java is enabled on the customer's web browser.

        :param java_enabled: The java_enabled of this Transaction.
        :type: bool
        """

        self._java_enabled = java_enabled
    
    @property
    def language(self):
        """Gets the language of this Transaction.

            The language that is linked to the object.

        :return: The language of this Transaction.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this Transaction.

            The language that is linked to the object.

        :param language: The language of this Transaction.
        :type: str
        """

        self._language = language
    
    @property
    def line_items(self):
        """Gets the line_items of this Transaction.

            The line items purchased by the customer.

        :return: The line_items of this Transaction.
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this Transaction.

            The line items purchased by the customer.

        :param line_items: The line_items of this Transaction.
        :type: list[LineItem]
        """

        self._line_items = line_items
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this Transaction.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this Transaction.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this Transaction.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this Transaction.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def merchant_reference(self):
        """Gets the merchant_reference of this Transaction.

            The merchant's reference used to identify the transaction.

        :return: The merchant_reference of this Transaction.
        :rtype: str
        """
        return self._merchant_reference

    @merchant_reference.setter
    def merchant_reference(self, merchant_reference):
        """Sets the merchant_reference of this Transaction.

            The merchant's reference used to identify the transaction.

        :param merchant_reference: The merchant_reference of this Transaction.
        :type: str
        """
        if merchant_reference is not None and len(merchant_reference) > 100:
            raise ValueError("Invalid value for `merchant_reference`, length must be less than or equal to `100`")

        self._merchant_reference = merchant_reference
    
    @property
    def meta_data(self):
        """Gets the meta_data of this Transaction.

            Allow to store additional information about the object.

        :return: The meta_data of this Transaction.
        :rtype: dict(str, str)
        """
        return self._meta_data

    @meta_data.setter
    def meta_data(self, meta_data):
        """Sets the meta_data of this Transaction.

            Allow to store additional information about the object.

        :param meta_data: The meta_data of this Transaction.
        :type: dict(str, str)
        """

        self._meta_data = meta_data
    
    @property
    def parent(self):
        """Gets the parent of this Transaction.

            The parent transaction which was (partially) replaced by this transaction.

        :return: The parent of this Transaction.
        :rtype: int
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this Transaction.

            The parent transaction which was (partially) replaced by this transaction.

        :param parent: The parent of this Transaction.
        :type: int
        """

        self._parent = parent
    
    @property
    def payment_connector_configuration(self):
        """Gets the payment_connector_configuration of this Transaction.

            The payment connector configuration that was used to authorize the transaction.

        :return: The payment_connector_configuration of this Transaction.
        :rtype: PaymentConnectorConfiguration
        """
        return self._payment_connector_configuration

    @payment_connector_configuration.setter
    def payment_connector_configuration(self, payment_connector_configuration):
        """Sets the payment_connector_configuration of this Transaction.

            The payment connector configuration that was used to authorize the transaction.

        :param payment_connector_configuration: The payment_connector_configuration of this Transaction.
        :type: PaymentConnectorConfiguration
        """

        self._payment_connector_configuration = payment_connector_configuration
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this Transaction.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this Transaction.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this Transaction.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this Transaction.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def processing_on(self):
        """Gets the processing_on of this Transaction.

            The date and time when the processing of the transaction was started.

        :return: The processing_on of this Transaction.
        :rtype: datetime
        """
        return self._processing_on

    @processing_on.setter
    def processing_on(self, processing_on):
        """Sets the processing_on of this Transaction.

            The date and time when the processing of the transaction was started.

        :param processing_on: The processing_on of this Transaction.
        :type: datetime
        """

        self._processing_on = processing_on
    
    @property
    def refunded_amount(self):
        """Gets the refunded_amount of this Transaction.

            The total amount that was refunded, in the transaction's currency.

        :return: The refunded_amount of this Transaction.
        :rtype: float
        """
        return self._refunded_amount

    @refunded_amount.setter
    def refunded_amount(self, refunded_amount):
        """Sets the refunded_amount of this Transaction.

            The total amount that was refunded, in the transaction's currency.

        :param refunded_amount: The refunded_amount of this Transaction.
        :type: float
        """

        self._refunded_amount = refunded_amount
    
    @property
    def screen_color_depth(self):
        """Gets the screen_color_depth of this Transaction.

            The screen color depth of the customer's web browser.

        :return: The screen_color_depth of this Transaction.
        :rtype: str
        """
        return self._screen_color_depth

    @screen_color_depth.setter
    def screen_color_depth(self, screen_color_depth):
        """Sets the screen_color_depth of this Transaction.

            The screen color depth of the customer's web browser.

        :param screen_color_depth: The screen_color_depth of this Transaction.
        :type: str
        """

        self._screen_color_depth = screen_color_depth
    
    @property
    def screen_height(self):
        """Gets the screen_height of this Transaction.

            The screen height of the customer's web browser.

        :return: The screen_height of this Transaction.
        :rtype: str
        """
        return self._screen_height

    @screen_height.setter
    def screen_height(self, screen_height):
        """Sets the screen_height of this Transaction.

            The screen height of the customer's web browser.

        :param screen_height: The screen_height of this Transaction.
        :type: str
        """

        self._screen_height = screen_height
    
    @property
    def screen_width(self):
        """Gets the screen_width of this Transaction.

            The screen width of the customer's web browser.

        :return: The screen_width of this Transaction.
        :rtype: str
        """
        return self._screen_width

    @screen_width.setter
    def screen_width(self, screen_width):
        """Sets the screen_width of this Transaction.

            The screen width of the customer's web browser.

        :param screen_width: The screen_width of this Transaction.
        :type: str
        """

        self._screen_width = screen_width
    
    @property
    def shipping_address(self):
        """Gets the shipping_address of this Transaction.

            The address to where the order will be shipped.

        :return: The shipping_address of this Transaction.
        :rtype: Address
        """
        return self._shipping_address

    @shipping_address.setter
    def shipping_address(self, shipping_address):
        """Sets the shipping_address of this Transaction.

            The address to where the order will be shipped.

        :param shipping_address: The shipping_address of this Transaction.
        :type: Address
        """

        self._shipping_address = shipping_address
    
    @property
    def shipping_method(self):
        """Gets the shipping_method of this Transaction.

            The name of the shipping method used to ship the products.

        :return: The shipping_method of this Transaction.
        :rtype: str
        """
        return self._shipping_method

    @shipping_method.setter
    def shipping_method(self, shipping_method):
        """Sets the shipping_method of this Transaction.

            The name of the shipping method used to ship the products.

        :param shipping_method: The shipping_method of this Transaction.
        :type: str
        """
        if shipping_method is not None and len(shipping_method) > 200:
            raise ValueError("Invalid value for `shipping_method`, length must be less than or equal to `200`")

        self._shipping_method = shipping_method
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this Transaction.

            The ID of the space view this object is linked to.

        :return: The space_view_id of this Transaction.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this Transaction.

            The ID of the space view this object is linked to.

        :param space_view_id: The space_view_id of this Transaction.
        :type: int
        """

        self._space_view_id = space_view_id
    
    @property
    def state(self):
        """Gets the state of this Transaction.

            The object's current state.

        :return: The state of this Transaction.
        :rtype: TransactionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Transaction.

            The object's current state.

        :param state: The state of this Transaction.
        :type: TransactionState
        """

        self._state = state
    
    @property
    def success_url(self):
        """Gets the success_url of this Transaction.

            The URL to redirect the customer back to after they successfully authenticated their payment.

        :return: The success_url of this Transaction.
        :rtype: str
        """
        return self._success_url

    @success_url.setter
    def success_url(self, success_url):
        """Sets the success_url of this Transaction.

            The URL to redirect the customer back to after they successfully authenticated their payment.

        :param success_url: The success_url of this Transaction.
        :type: str
        """
        if success_url is not None and len(success_url) > 2000:
            raise ValueError("Invalid value for `success_url`, length must be less than or equal to `2000`")
        if success_url is not None and len(success_url) < 9:
            raise ValueError("Invalid value for `success_url`, length must be greater than or equal to `9`")

        self._success_url = success_url
    
    @property
    def terminal(self):
        """Gets the terminal of this Transaction.

            The payment terminal through which the payment was processed.

        :return: The terminal of this Transaction.
        :rtype: PaymentTerminal
        """
        return self._terminal

    @terminal.setter
    def terminal(self, terminal):
        """Sets the terminal of this Transaction.

            The payment terminal through which the payment was processed.

        :param terminal: The terminal of this Transaction.
        :type: PaymentTerminal
        """

        self._terminal = terminal
    
    @property
    def time_zone(self):
        """Gets the time_zone of this Transaction.

            The customer's time zone, which affects how dates and times are formatted when communicating with the customer.

        :return: The time_zone of this Transaction.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this Transaction.

            The customer's time zone, which affects how dates and times are formatted when communicating with the customer.

        :param time_zone: The time_zone of this Transaction.
        :type: str
        """

        self._time_zone = time_zone
    
    @property
    def token(self):
        """Gets the token of this Transaction.

            The payment token that should be used to charge the customer.

        :return: The token of this Transaction.
        :rtype: Token
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this Transaction.

            The payment token that should be used to charge the customer.

        :param token: The token of this Transaction.
        :type: Token
        """

        self._token = token
    
    @property
    def tokenization_mode(self):
        """Gets the tokenization_mode of this Transaction.

            The tokenization mode specifies whether and how the tokenization of payment information is applied to the transaction.

        :return: The tokenization_mode of this Transaction.
        :rtype: TokenizationMode
        """
        return self._tokenization_mode

    @tokenization_mode.setter
    def tokenization_mode(self, tokenization_mode):
        """Sets the tokenization_mode of this Transaction.

            The tokenization mode specifies whether and how the tokenization of payment information is applied to the transaction.

        :param tokenization_mode: The tokenization_mode of this Transaction.
        :type: TokenizationMode
        """

        self._tokenization_mode = tokenization_mode
    
    @property
    def total_applied_fees(self):
        """Gets the total_applied_fees of this Transaction.

            The total of all fees charged, in the transaction's currency.

        :return: The total_applied_fees of this Transaction.
        :rtype: float
        """
        return self._total_applied_fees

    @total_applied_fees.setter
    def total_applied_fees(self, total_applied_fees):
        """Sets the total_applied_fees of this Transaction.

            The total of all fees charged, in the transaction's currency.

        :param total_applied_fees: The total_applied_fees of this Transaction.
        :type: float
        """

        self._total_applied_fees = total_applied_fees
    
    @property
    def total_settled_amount(self):
        """Gets the total_settled_amount of this Transaction.

            The total amount that was settled, in the transaction's currency.

        :return: The total_settled_amount of this Transaction.
        :rtype: float
        """
        return self._total_settled_amount

    @total_settled_amount.setter
    def total_settled_amount(self, total_settled_amount):
        """Sets the total_settled_amount of this Transaction.

            The total amount that was settled, in the transaction's currency.

        :param total_settled_amount: The total_settled_amount of this Transaction.
        :type: float
        """

        self._total_settled_amount = total_settled_amount
    
    @property
    def user_agent_header(self):
        """Gets the user_agent_header of this Transaction.

            The 'User Agent' header of the customer's web browser.

        :return: The user_agent_header of this Transaction.
        :rtype: str
        """
        return self._user_agent_header

    @user_agent_header.setter
    def user_agent_header(self, user_agent_header):
        """Sets the user_agent_header of this Transaction.

            The 'User Agent' header of the customer's web browser.

        :param user_agent_header: The user_agent_header of this Transaction.
        :type: str
        """

        self._user_agent_header = user_agent_header
    
    @property
    def user_failure_message(self):
        """Gets the user_failure_message of this Transaction.

            The message that can be displayed to the customer explaining why the transaction failed, in the customer's language.

        :return: The user_failure_message of this Transaction.
        :rtype: str
        """
        return self._user_failure_message

    @user_failure_message.setter
    def user_failure_message(self, user_failure_message):
        """Sets the user_failure_message of this Transaction.

            The message that can be displayed to the customer explaining why the transaction failed, in the customer's language.

        :param user_failure_message: The user_failure_message of this Transaction.
        :type: str
        """

        self._user_failure_message = user_failure_message
    
    @property
    def user_interface_type(self):
        """Gets the user_interface_type of this Transaction.

            The type of user interface the customer used to provide the payment information.

        :return: The user_interface_type of this Transaction.
        :rtype: TransactionUserInterfaceType
        """
        return self._user_interface_type

    @user_interface_type.setter
    def user_interface_type(self, user_interface_type):
        """Sets the user_interface_type of this Transaction.

            The type of user interface the customer used to provide the payment information.

        :param user_interface_type: The user_interface_type of this Transaction.
        :type: TransactionUserInterfaceType
        """

        self._user_interface_type = user_interface_type
    
    @property
    def version(self):
        """Gets the version of this Transaction.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this Transaction.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Transaction.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this Transaction.
        :type: int
        """

        self._version = version
    
    @property
    def window_height(self):
        """Gets the window_height of this Transaction.

            The window height of the customer's web browser.

        :return: The window_height of this Transaction.
        :rtype: str
        """
        return self._window_height

    @window_height.setter
    def window_height(self, window_height):
        """Sets the window_height of this Transaction.

            The window height of the customer's web browser.

        :param window_height: The window_height of this Transaction.
        :type: str
        """

        self._window_height = window_height
    
    @property
    def window_width(self):
        """Gets the window_width of this Transaction.

            The window width of the customer's web browser.

        :return: The window_width of this Transaction.
        :rtype: str
        """
        return self._window_width

    @window_width.setter
    def window_width(self, window_width):
        """Sets the window_width of this Transaction.

            The window width of the customer's web browser.

        :param window_width: The window_width of this Transaction.
        :type: str
        """

        self._window_width = window_width
    
    @property
    def years_to_keep(self):
        """Gets the years_to_keep of this Transaction.

            The number of years the transaction is kept after its authorization.

        :return: The years_to_keep of this Transaction.
        :rtype: int
        """
        return self._years_to_keep

    @years_to_keep.setter
    def years_to_keep(self, years_to_keep):
        """Sets the years_to_keep of this Transaction.

            The number of years the transaction is kept after its authorization.

        :param years_to_keep: The years_to_keep of this Transaction.
        :type: int
        """

        self._years_to_keep = years_to_keep
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(Transaction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, Transaction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentTerminalConfigurationVersion:

    swagger_types = {
    
        'configuration': 'PaymentTerminalConfiguration',
        'connector_configurations': 'list[int]',
        'created_by': 'int',
        'created_on': 'datetime',
        'default_currency': 'str',
        'id': 'int',
        'linked_space_id': 'int',
        'maintenance_window_duration': 'str',
        'maintenance_window_start': 'str',
        'planned_purge_date': 'datetime',
        'state': 'PaymentTerminalConfigurationVersionState',
        'time_zone': 'str',
        'version': 'int',
        'version_applied_immediately': 'bool',
    }

    attribute_map = {
        'configuration': 'configuration','connector_configurations': 'connectorConfigurations','created_by': 'createdBy','created_on': 'createdOn','default_currency': 'defaultCurrency','id': 'id','linked_space_id': 'linkedSpaceId','maintenance_window_duration': 'maintenanceWindowDuration','maintenance_window_start': 'maintenanceWindowStart','planned_purge_date': 'plannedPurgeDate','state': 'state','time_zone': 'timeZone','version': 'version','version_applied_immediately': 'versionAppliedImmediately',
    }

    
    _configuration = None
    _connector_configurations = None
    _created_by = None
    _created_on = None
    _default_currency = None
    _id = None
    _linked_space_id = None
    _maintenance_window_duration = None
    _maintenance_window_start = None
    _planned_purge_date = None
    _state = None
    _time_zone = None
    _version = None
    _version_applied_immediately = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.configuration = kwargs.get('configuration', None)
        self.connector_configurations = kwargs.get('connector_configurations', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_on = kwargs.get('created_on', None)
        self.default_currency = kwargs.get('default_currency', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.maintenance_window_duration = kwargs.get('maintenance_window_duration', None)
        self.maintenance_window_start = kwargs.get('maintenance_window_start', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.state = kwargs.get('state', None)
        self.time_zone = kwargs.get('time_zone', None)
        self.version = kwargs.get('version', None)
        self.version_applied_immediately = kwargs.get('version_applied_immediately', None)
        

    
    @property
    def configuration(self):
        """Gets the configuration of this PaymentTerminalConfigurationVersion.

            The payment terminal configuration that the version belongs to.

        :return: The configuration of this PaymentTerminalConfigurationVersion.
        :rtype: PaymentTerminalConfiguration
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this PaymentTerminalConfigurationVersion.

            The payment terminal configuration that the version belongs to.

        :param configuration: The configuration of this PaymentTerminalConfigurationVersion.
        :type: PaymentTerminalConfiguration
        """

        self._configuration = configuration
    
    @property
    def connector_configurations(self):
        """Gets the connector_configurations of this PaymentTerminalConfigurationVersion.

            The payment connector configurations that are available on the payment terminal.

        :return: The connector_configurations of this PaymentTerminalConfigurationVersion.
        :rtype: list[int]
        """
        return self._connector_configurations

    @connector_configurations.setter
    def connector_configurations(self, connector_configurations):
        """Sets the connector_configurations of this PaymentTerminalConfigurationVersion.

            The payment connector configurations that are available on the payment terminal.

        :param connector_configurations: The connector_configurations of this PaymentTerminalConfigurationVersion.
        :type: list[int]
        """

        self._connector_configurations = connector_configurations
    
    @property
    def created_by(self):
        """Gets the created_by of this PaymentTerminalConfigurationVersion.

            The ID of the user the payment terminal configuration version was created by.

        :return: The created_by of this PaymentTerminalConfigurationVersion.
        :rtype: int
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this PaymentTerminalConfigurationVersion.

            The ID of the user the payment terminal configuration version was created by.

        :param created_by: The created_by of this PaymentTerminalConfigurationVersion.
        :type: int
        """

        self._created_by = created_by
    
    @property
    def created_on(self):
        """Gets the created_on of this PaymentTerminalConfigurationVersion.

            The date and time when the object was created.

        :return: The created_on of this PaymentTerminalConfigurationVersion.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this PaymentTerminalConfigurationVersion.

            The date and time when the object was created.

        :param created_on: The created_on of this PaymentTerminalConfigurationVersion.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def default_currency(self):
        """Gets the default_currency of this PaymentTerminalConfigurationVersion.

            The default currency that is used if none is set on the payment terminal itself. If it is empty, the currency is derived from the location of the terminal.

        :return: The default_currency of this PaymentTerminalConfigurationVersion.
        :rtype: str
        """
        return self._default_currency

    @default_currency.setter
    def default_currency(self, default_currency):
        """Sets the default_currency of this PaymentTerminalConfigurationVersion.

            The default currency that is used if none is set on the payment terminal itself. If it is empty, the currency is derived from the location of the terminal.

        :param default_currency: The default_currency of this PaymentTerminalConfigurationVersion.
        :type: str
        """

        self._default_currency = default_currency
    
    @property
    def id(self):
        """Gets the id of this PaymentTerminalConfigurationVersion.

            A unique identifier for the object.

        :return: The id of this PaymentTerminalConfigurationVersion.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentTerminalConfigurationVersion.

            A unique identifier for the object.

        :param id: The id of this PaymentTerminalConfigurationVersion.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this PaymentTerminalConfigurationVersion.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this PaymentTerminalConfigurationVersion.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this PaymentTerminalConfigurationVersion.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this PaymentTerminalConfigurationVersion.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def maintenance_window_duration(self):
        """Gets the maintenance_window_duration of this PaymentTerminalConfigurationVersion.

            The permitted duration of the terminal's maintenance window.

        :return: The maintenance_window_duration of this PaymentTerminalConfigurationVersion.
        :rtype: str
        """
        return self._maintenance_window_duration

    @maintenance_window_duration.setter
    def maintenance_window_duration(self, maintenance_window_duration):
        """Sets the maintenance_window_duration of this PaymentTerminalConfigurationVersion.

            The permitted duration of the terminal's maintenance window.

        :param maintenance_window_duration: The maintenance_window_duration of this PaymentTerminalConfigurationVersion.
        :type: str
        """

        self._maintenance_window_duration = maintenance_window_duration
    
    @property
    def maintenance_window_start(self):
        """Gets the maintenance_window_start of this PaymentTerminalConfigurationVersion.

            The start time of the terminal's maintenance window.

        :return: The maintenance_window_start of this PaymentTerminalConfigurationVersion.
        :rtype: str
        """
        return self._maintenance_window_start

    @maintenance_window_start.setter
    def maintenance_window_start(self, maintenance_window_start):
        """Sets the maintenance_window_start of this PaymentTerminalConfigurationVersion.

            The start time of the terminal's maintenance window.

        :param maintenance_window_start: The maintenance_window_start of this PaymentTerminalConfigurationVersion.
        :type: str
        """

        self._maintenance_window_start = maintenance_window_start
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this PaymentTerminalConfigurationVersion.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this PaymentTerminalConfigurationVersion.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this PaymentTerminalConfigurationVersion.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this PaymentTerminalConfigurationVersion.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def state(self):
        """Gets the state of this PaymentTerminalConfigurationVersion.

            The object's current state.

        :return: The state of this PaymentTerminalConfigurationVersion.
        :rtype: PaymentTerminalConfigurationVersionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PaymentTerminalConfigurationVersion.

            The object's current state.

        :param state: The state of this PaymentTerminalConfigurationVersion.
        :type: PaymentTerminalConfigurationVersionState
        """

        self._state = state
    
    @property
    def time_zone(self):
        """Gets the time_zone of this PaymentTerminalConfigurationVersion.

            The time zone of the payment terminal used to determine the maintenance window.

        :return: The time_zone of this PaymentTerminalConfigurationVersion.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this PaymentTerminalConfigurationVersion.

            The time zone of the payment terminal used to determine the maintenance window.

        :param time_zone: The time_zone of this PaymentTerminalConfigurationVersion.
        :type: str
        """

        self._time_zone = time_zone
    
    @property
    def version(self):
        """Gets the version of this PaymentTerminalConfigurationVersion.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this PaymentTerminalConfigurationVersion.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentTerminalConfigurationVersion.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this PaymentTerminalConfigurationVersion.
        :type: int
        """

        self._version = version
    
    @property
    def version_applied_immediately(self):
        """Gets the version_applied_immediately of this PaymentTerminalConfigurationVersion.

            Whether payment terminals are immediately updated to this configuration version. If not, it will be applied during the maintenance window.

        :return: The version_applied_immediately of this PaymentTerminalConfigurationVersion.
        :rtype: bool
        """
        return self._version_applied_immediately

    @version_applied_immediately.setter
    def version_applied_immediately(self, version_applied_immediately):
        """Sets the version_applied_immediately of this PaymentTerminalConfigurationVersion.

            Whether payment terminals are immediately updated to this configuration version. If not, it will be applied during the maintenance window.

        :param version_applied_immediately: The version_applied_immediately of this PaymentTerminalConfigurationVersion.
        :type: bool
        """

        self._version_applied_immediately = version_applied_immediately
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentTerminalConfigurationVersion, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentTerminalConfigurationVersion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class DebtCollectionCase:

    swagger_types = {
    
        'amount': 'float',
        'billing_address': 'Address',
        'closed_on': 'datetime',
        'collector_configuration': 'DebtCollectorConfiguration',
        'contract_date': 'datetime',
        'created_on': 'datetime',
        'creator': 'int',
        'currency': 'str',
        'due_date': 'datetime',
        'environment': 'DebtCollectionEnvironment',
        'external_id': 'str',
        'failed_on': 'datetime',
        'failure_reason': 'FailureReason',
        'id': 'int',
        'labels': 'list[Label]',
        'language': 'str',
        'line_items': 'list[LineItem]',
        'linked_space_id': 'int',
        'next_attempt_on': 'datetime',
        'planned_purge_date': 'datetime',
        'processing_started_on': 'datetime',
        'processing_timeout_on': 'datetime',
        'reference': 'str',
        'review_started_on': 'datetime',
        'reviewed_on': 'datetime',
        'reviewer': 'int',
        'source': 'DebtCollectionCaseSource',
        'source_entity_id': 'int',
        'space_view_id': 'int',
        'state': 'DebtCollectionCaseState',
        'version': 'int',
    }

    attribute_map = {
        'amount': 'amount','billing_address': 'billingAddress','closed_on': 'closedOn','collector_configuration': 'collectorConfiguration','contract_date': 'contractDate','created_on': 'createdOn','creator': 'creator','currency': 'currency','due_date': 'dueDate','environment': 'environment','external_id': 'externalId','failed_on': 'failedOn','failure_reason': 'failureReason','id': 'id','labels': 'labels','language': 'language','line_items': 'lineItems','linked_space_id': 'linkedSpaceId','next_attempt_on': 'nextAttemptOn','planned_purge_date': 'plannedPurgeDate','processing_started_on': 'processingStartedOn','processing_timeout_on': 'processingTimeoutOn','reference': 'reference','review_started_on': 'reviewStartedOn','reviewed_on': 'reviewedOn','reviewer': 'reviewer','source': 'source','source_entity_id': 'sourceEntityId','space_view_id': 'spaceViewId','state': 'state','version': 'version',
    }

    
    _amount = None
    _billing_address = None
    _closed_on = None
    _collector_configuration = None
    _contract_date = None
    _created_on = None
    _creator = None
    _currency = None
    _due_date = None
    _environment = None
    _external_id = None
    _failed_on = None
    _failure_reason = None
    _id = None
    _labels = None
    _language = None
    _line_items = None
    _linked_space_id = None
    _next_attempt_on = None
    _planned_purge_date = None
    _processing_started_on = None
    _processing_timeout_on = None
    _reference = None
    _review_started_on = None
    _reviewed_on = None
    _reviewer = None
    _source = None
    _source_entity_id = None
    _space_view_id = None
    _state = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.amount = kwargs.get('amount', None)
        self.billing_address = kwargs.get('billing_address', None)
        self.closed_on = kwargs.get('closed_on', None)
        self.collector_configuration = kwargs.get('collector_configuration', None)
        self.contract_date = kwargs.get('contract_date', None)
        self.created_on = kwargs.get('created_on', None)
        self.creator = kwargs.get('creator', None)
        self.currency = kwargs.get('currency', None)
        self.due_date = kwargs.get('due_date', None)
        self.environment = kwargs.get('environment', None)
        self.external_id = kwargs.get('external_id', None)
        self.failed_on = kwargs.get('failed_on', None)
        self.failure_reason = kwargs.get('failure_reason', None)
        self.id = kwargs.get('id', None)
        self.labels = kwargs.get('labels', None)
        self.language = kwargs.get('language', None)
        self.line_items = kwargs.get('line_items', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.next_attempt_on = kwargs.get('next_attempt_on', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.processing_started_on = kwargs.get('processing_started_on', None)
        self.processing_timeout_on = kwargs.get('processing_timeout_on', None)
        self.reference = kwargs.get('reference', None)
        self.review_started_on = kwargs.get('review_started_on', None)
        self.reviewed_on = kwargs.get('reviewed_on', None)
        self.reviewer = kwargs.get('reviewer', None)
        self.source = kwargs.get('source', None)
        self.source_entity_id = kwargs.get('source_entity_id', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        self.state = kwargs.get('state', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def amount(self):
        """Gets the amount of this DebtCollectionCase.

            The sum of all unpaid item prices in the case's currency. The amount can no longer be changed once the case has been reviewed.

        :return: The amount of this DebtCollectionCase.
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this DebtCollectionCase.

            The sum of all unpaid item prices in the case's currency. The amount can no longer be changed once the case has been reviewed.

        :param amount: The amount of this DebtCollectionCase.
        :type: float
        """

        self._amount = amount
    
    @property
    def billing_address(self):
        """Gets the billing_address of this DebtCollectionCase.

            The billing address that identifies the debtor.

        :return: The billing_address of this DebtCollectionCase.
        :rtype: Address
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this DebtCollectionCase.

            The billing address that identifies the debtor.

        :param billing_address: The billing_address of this DebtCollectionCase.
        :type: Address
        """

        self._billing_address = billing_address
    
    @property
    def closed_on(self):
        """Gets the closed_on of this DebtCollectionCase.

            The date and time when the case was closed.

        :return: The closed_on of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._closed_on

    @closed_on.setter
    def closed_on(self, closed_on):
        """Sets the closed_on of this DebtCollectionCase.

            The date and time when the case was closed.

        :param closed_on: The closed_on of this DebtCollectionCase.
        :type: datetime
        """

        self._closed_on = closed_on
    
    @property
    def collector_configuration(self):
        """Gets the collector_configuration of this DebtCollectionCase.

            The configuration that the case is processed with.

        :return: The collector_configuration of this DebtCollectionCase.
        :rtype: DebtCollectorConfiguration
        """
        return self._collector_configuration

    @collector_configuration.setter
    def collector_configuration(self, collector_configuration):
        """Sets the collector_configuration of this DebtCollectionCase.

            The configuration that the case is processed with.

        :param collector_configuration: The collector_configuration of this DebtCollectionCase.
        :type: DebtCollectorConfiguration
        """

        self._collector_configuration = collector_configuration
    
    @property
    def contract_date(self):
        """Gets the contract_date of this DebtCollectionCase.

            The date and time when the contract with the debtor was signed.

        :return: The contract_date of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._contract_date

    @contract_date.setter
    def contract_date(self, contract_date):
        """Sets the contract_date of this DebtCollectionCase.

            The date and time when the contract with the debtor was signed.

        :param contract_date: The contract_date of this DebtCollectionCase.
        :type: datetime
        """

        self._contract_date = contract_date
    
    @property
    def created_on(self):
        """Gets the created_on of this DebtCollectionCase.

            The date and time when the object was created.

        :return: The created_on of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this DebtCollectionCase.

            The date and time when the object was created.

        :param created_on: The created_on of this DebtCollectionCase.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def creator(self):
        """Gets the creator of this DebtCollectionCase.

            The ID of the user the case was created by.

        :return: The creator of this DebtCollectionCase.
        :rtype: int
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """Sets the creator of this DebtCollectionCase.

            The ID of the user the case was created by.

        :param creator: The creator of this DebtCollectionCase.
        :type: int
        """

        self._creator = creator
    
    @property
    def currency(self):
        """Gets the currency of this DebtCollectionCase.

            The three-letter code (ISO 4217 format) of the case's currency.

        :return: The currency of this DebtCollectionCase.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this DebtCollectionCase.

            The three-letter code (ISO 4217 format) of the case's currency.

        :param currency: The currency of this DebtCollectionCase.
        :type: str
        """

        self._currency = currency
    
    @property
    def due_date(self):
        """Gets the due_date of this DebtCollectionCase.

            The date and time when the claim was due.

        :return: The due_date of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this DebtCollectionCase.

            The date and time when the claim was due.

        :param due_date: The due_date of this DebtCollectionCase.
        :type: datetime
        """

        self._due_date = due_date
    
    @property
    def environment(self):
        """Gets the environment of this DebtCollectionCase.

            The environment in which the case is processed.

        :return: The environment of this DebtCollectionCase.
        :rtype: DebtCollectionEnvironment
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this DebtCollectionCase.

            The environment in which the case is processed.

        :param environment: The environment of this DebtCollectionCase.
        :type: DebtCollectionEnvironment
        """

        self._environment = environment
    
    @property
    def external_id(self):
        """Gets the external_id of this DebtCollectionCase.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :return: The external_id of this DebtCollectionCase.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this DebtCollectionCase.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :param external_id: The external_id of this DebtCollectionCase.
        :type: str
        """

        self._external_id = external_id
    
    @property
    def failed_on(self):
        """Gets the failed_on of this DebtCollectionCase.

            The date and time when the case failed.

        :return: The failed_on of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._failed_on

    @failed_on.setter
    def failed_on(self, failed_on):
        """Sets the failed_on of this DebtCollectionCase.

            The date and time when the case failed.

        :param failed_on: The failed_on of this DebtCollectionCase.
        :type: datetime
        """

        self._failed_on = failed_on
    
    @property
    def failure_reason(self):
        """Gets the failure_reason of this DebtCollectionCase.

            The reason for the failure of the case.

        :return: The failure_reason of this DebtCollectionCase.
        :rtype: FailureReason
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """Sets the failure_reason of this DebtCollectionCase.

            The reason for the failure of the case.

        :param failure_reason: The failure_reason of this DebtCollectionCase.
        :type: FailureReason
        """

        self._failure_reason = failure_reason
    
    @property
    def id(self):
        """Gets the id of this DebtCollectionCase.

            A unique identifier for the object.

        :return: The id of this DebtCollectionCase.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DebtCollectionCase.

            A unique identifier for the object.

        :param id: The id of this DebtCollectionCase.
        :type: int
        """

        self._id = id
    
    @property
    def labels(self):
        """Gets the labels of this DebtCollectionCase.

            The labels providing additional information about the object.

        :return: The labels of this DebtCollectionCase.
        :rtype: list[Label]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this DebtCollectionCase.

            The labels providing additional information about the object.

        :param labels: The labels of this DebtCollectionCase.
        :type: list[Label]
        """

        self._labels = labels
    
    @property
    def language(self):
        """Gets the language of this DebtCollectionCase.

            The language that is linked to the object.

        :return: The language of this DebtCollectionCase.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this DebtCollectionCase.

            The language that is linked to the object.

        :param language: The language of this DebtCollectionCase.
        :type: str
        """

        self._language = language
    
    @property
    def line_items(self):
        """Gets the line_items of this DebtCollectionCase.

            The line items that are subject of this debt collection case.

        :return: The line_items of this DebtCollectionCase.
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this DebtCollectionCase.

            The line items that are subject of this debt collection case.

        :param line_items: The line_items of this DebtCollectionCase.
        :type: list[LineItem]
        """

        self._line_items = line_items
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this DebtCollectionCase.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this DebtCollectionCase.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this DebtCollectionCase.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this DebtCollectionCase.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def next_attempt_on(self):
        """Gets the next_attempt_on of this DebtCollectionCase.

            The date and time when the next attempt at processing the case will be made.

        :return: The next_attempt_on of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._next_attempt_on

    @next_attempt_on.setter
    def next_attempt_on(self, next_attempt_on):
        """Sets the next_attempt_on of this DebtCollectionCase.

            The date and time when the next attempt at processing the case will be made.

        :param next_attempt_on: The next_attempt_on of this DebtCollectionCase.
        :type: datetime
        """

        self._next_attempt_on = next_attempt_on
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this DebtCollectionCase.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this DebtCollectionCase.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this DebtCollectionCase.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def processing_started_on(self):
        """Gets the processing_started_on of this DebtCollectionCase.

            The date and time when the processing of the case was started.

        :return: The processing_started_on of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._processing_started_on

    @processing_started_on.setter
    def processing_started_on(self, processing_started_on):
        """Sets the processing_started_on of this DebtCollectionCase.

            The date and time when the processing of the case was started.

        :param processing_started_on: The processing_started_on of this DebtCollectionCase.
        :type: datetime
        """

        self._processing_started_on = processing_started_on
    
    @property
    def processing_timeout_on(self):
        """Gets the processing_timeout_on of this DebtCollectionCase.

            The date and time when the processing of the case times out.

        :return: The processing_timeout_on of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._processing_timeout_on

    @processing_timeout_on.setter
    def processing_timeout_on(self, processing_timeout_on):
        """Sets the processing_timeout_on of this DebtCollectionCase.

            The date and time when the processing of the case times out.

        :param processing_timeout_on: The processing_timeout_on of this DebtCollectionCase.
        :type: datetime
        """

        self._processing_timeout_on = processing_timeout_on
    
    @property
    def reference(self):
        """Gets the reference of this DebtCollectionCase.

            A unique reference to identify the debt collection case in communication with the debtor.

        :return: The reference of this DebtCollectionCase.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this DebtCollectionCase.

            A unique reference to identify the debt collection case in communication with the debtor.

        :param reference: The reference of this DebtCollectionCase.
        :type: str
        """

        self._reference = reference
    
    @property
    def review_started_on(self):
        """Gets the review_started_on of this DebtCollectionCase.

            The date and time when the review of the case was started.

        :return: The review_started_on of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._review_started_on

    @review_started_on.setter
    def review_started_on(self, review_started_on):
        """Sets the review_started_on of this DebtCollectionCase.

            The date and time when the review of the case was started.

        :param review_started_on: The review_started_on of this DebtCollectionCase.
        :type: datetime
        """

        self._review_started_on = review_started_on
    
    @property
    def reviewed_on(self):
        """Gets the reviewed_on of this DebtCollectionCase.

            The date and time when the case was reviewed.

        :return: The reviewed_on of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._reviewed_on

    @reviewed_on.setter
    def reviewed_on(self, reviewed_on):
        """Sets the reviewed_on of this DebtCollectionCase.

            The date and time when the case was reviewed.

        :param reviewed_on: The reviewed_on of this DebtCollectionCase.
        :type: datetime
        """

        self._reviewed_on = reviewed_on
    
    @property
    def reviewer(self):
        """Gets the reviewer of this DebtCollectionCase.

            The ID of the user the case was reviewed by.

        :return: The reviewer of this DebtCollectionCase.
        :rtype: int
        """
        return self._reviewer

    @reviewer.setter
    def reviewer(self, reviewer):
        """Sets the reviewer of this DebtCollectionCase.

            The ID of the user the case was reviewed by.

        :param reviewer: The reviewer of this DebtCollectionCase.
        :type: int
        """

        self._reviewer = reviewer
    
    @property
    def source(self):
        """Gets the source of this DebtCollectionCase.

            The source of the case stating the origin of the claim.

        :return: The source of this DebtCollectionCase.
        :rtype: DebtCollectionCaseSource
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this DebtCollectionCase.

            The source of the case stating the origin of the claim.

        :param source: The source of this DebtCollectionCase.
        :type: DebtCollectionCaseSource
        """

        self._source = source
    
    @property
    def source_entity_id(self):
        """Gets the source_entity_id of this DebtCollectionCase.

            The ID of the object that is the source of the case. Only defined if the case was created by an internal process.

        :return: The source_entity_id of this DebtCollectionCase.
        :rtype: int
        """
        return self._source_entity_id

    @source_entity_id.setter
    def source_entity_id(self, source_entity_id):
        """Sets the source_entity_id of this DebtCollectionCase.

            The ID of the object that is the source of the case. Only defined if the case was created by an internal process.

        :param source_entity_id: The source_entity_id of this DebtCollectionCase.
        :type: int
        """

        self._source_entity_id = source_entity_id
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this DebtCollectionCase.

            The ID of the space view this object is linked to.

        :return: The space_view_id of this DebtCollectionCase.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this DebtCollectionCase.

            The ID of the space view this object is linked to.

        :param space_view_id: The space_view_id of this DebtCollectionCase.
        :type: int
        """

        self._space_view_id = space_view_id
    
    @property
    def state(self):
        """Gets the state of this DebtCollectionCase.

            The object's current state.

        :return: The state of this DebtCollectionCase.
        :rtype: DebtCollectionCaseState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this DebtCollectionCase.

            The object's current state.

        :param state: The state of this DebtCollectionCase.
        :type: DebtCollectionCaseState
        """

        self._state = state
    
    @property
    def version(self):
        """Gets the version of this DebtCollectionCase.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this DebtCollectionCase.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this DebtCollectionCase.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this DebtCollectionCase.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(DebtCollectionCase, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, DebtCollectionCase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class ShopifySubscriberCreation:

    swagger_types = {
    
        'email_address': 'str',
        'phone_number': 'str',
        'shopify_customer_gid': 'str',
        'shopify_customer_id': 'str',
    }

    attribute_map = {
        'email_address': 'emailAddress','phone_number': 'phoneNumber','shopify_customer_gid': 'shopifyCustomerGid','shopify_customer_id': 'shopifyCustomerId',
    }

    
    _email_address = None
    _phone_number = None
    _shopify_customer_gid = None
    _shopify_customer_id = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.email_address = kwargs.get('email_address', None)
        self.phone_number = kwargs.get('phone_number', None)
        self.shopify_customer_gid = kwargs.get('shopify_customer_gid', None)
        self.shopify_customer_id = kwargs.get('shopify_customer_id')

        

    
    @property
    def email_address(self):
        """Gets the email_address of this ShopifySubscriberCreation.

            

        :return: The email_address of this ShopifySubscriberCreation.
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this ShopifySubscriberCreation.

            

        :param email_address: The email_address of this ShopifySubscriberCreation.
        :type: str
        """

        self._email_address = email_address
    
    @property
    def phone_number(self):
        """Gets the phone_number of this ShopifySubscriberCreation.

            

        :return: The phone_number of this ShopifySubscriberCreation.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this ShopifySubscriberCreation.

            

        :param phone_number: The phone_number of this ShopifySubscriberCreation.
        :type: str
        """

        self._phone_number = phone_number
    
    @property
    def shopify_customer_gid(self):
        """Gets the shopify_customer_gid of this ShopifySubscriberCreation.

            The customer Global ID has to correspond to the Global ID assigned to the customer by Shopify. When the subscriber already exists no new subscriber will be created.

        :return: The shopify_customer_gid of this ShopifySubscriberCreation.
        :rtype: str
        """
        return self._shopify_customer_gid

    @shopify_customer_gid.setter
    def shopify_customer_gid(self, shopify_customer_gid):
        """Sets the shopify_customer_gid of this ShopifySubscriberCreation.

            The customer Global ID has to correspond to the Global ID assigned to the customer by Shopify. When the subscriber already exists no new subscriber will be created.

        :param shopify_customer_gid: The shopify_customer_gid of this ShopifySubscriberCreation.
        :type: str
        """

        self._shopify_customer_gid = shopify_customer_gid
    
    @property
    def shopify_customer_id(self):
        """Gets the shopify_customer_id of this ShopifySubscriberCreation.

            The customer ID has to correspond to the ID assigned to the customer by Shopify. When the subscriber already exists no new subscriber will be created.

        :return: The shopify_customer_id of this ShopifySubscriberCreation.
        :rtype: str
        """
        return self._shopify_customer_id

    @shopify_customer_id.setter
    def shopify_customer_id(self, shopify_customer_id):
        """Sets the shopify_customer_id of this ShopifySubscriberCreation.

            The customer ID has to correspond to the ID assigned to the customer by Shopify. When the subscriber already exists no new subscriber will be created.

        :param shopify_customer_id: The shopify_customer_id of this ShopifySubscriberCreation.
        :type: str
        """
        if shopify_customer_id is None:
            raise ValueError("Invalid value for `shopify_customer_id`, must not be `None`")

        self._shopify_customer_id = shopify_customer_id
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ShopifySubscriberCreation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ShopifySubscriberCreation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class BillingCycleModel:

    swagger_types = {
    
        'billing_cycle_type': 'BillingCycleType',
        'customization': 'BillingDayCustomization',
        'day_of_month': 'int',
        'month': 'DisplayableMonth',
        'number_of_periods': 'int',
        'weekly_day': 'DisplayableDayOfWeek',
    }

    attribute_map = {
        'billing_cycle_type': 'billingCycleType','customization': 'customization','day_of_month': 'dayOfMonth','month': 'month','number_of_periods': 'numberOfPeriods','weekly_day': 'weeklyDay',
    }

    
    _billing_cycle_type = None
    _customization = None
    _day_of_month = None
    _month = None
    _number_of_periods = None
    _weekly_day = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.billing_cycle_type = kwargs.get('billing_cycle_type')

        self.customization = kwargs.get('customization', None)
        self.day_of_month = kwargs.get('day_of_month', None)
        self.month = kwargs.get('month', None)
        self.number_of_periods = kwargs.get('number_of_periods')

        self.weekly_day = kwargs.get('weekly_day', None)
        

    
    @property
    def billing_cycle_type(self):
        """Gets the billing_cycle_type of this BillingCycleModel.

            

        :return: The billing_cycle_type of this BillingCycleModel.
        :rtype: BillingCycleType
        """
        return self._billing_cycle_type

    @billing_cycle_type.setter
    def billing_cycle_type(self, billing_cycle_type):
        """Sets the billing_cycle_type of this BillingCycleModel.

            

        :param billing_cycle_type: The billing_cycle_type of this BillingCycleModel.
        :type: BillingCycleType
        """
        if billing_cycle_type is None:
            raise ValueError("Invalid value for `billing_cycle_type`, must not be `None`")

        self._billing_cycle_type = billing_cycle_type
    
    @property
    def customization(self):
        """Gets the customization of this BillingCycleModel.

            

        :return: The customization of this BillingCycleModel.
        :rtype: BillingDayCustomization
        """
        return self._customization

    @customization.setter
    def customization(self, customization):
        """Sets the customization of this BillingCycleModel.

            

        :param customization: The customization of this BillingCycleModel.
        :type: BillingDayCustomization
        """

        self._customization = customization
    
    @property
    def day_of_month(self):
        """Gets the day_of_month of this BillingCycleModel.

            

        :return: The day_of_month of this BillingCycleModel.
        :rtype: int
        """
        return self._day_of_month

    @day_of_month.setter
    def day_of_month(self, day_of_month):
        """Sets the day_of_month of this BillingCycleModel.

            

        :param day_of_month: The day_of_month of this BillingCycleModel.
        :type: int
        """

        self._day_of_month = day_of_month
    
    @property
    def month(self):
        """Gets the month of this BillingCycleModel.

            

        :return: The month of this BillingCycleModel.
        :rtype: DisplayableMonth
        """
        return self._month

    @month.setter
    def month(self, month):
        """Sets the month of this BillingCycleModel.

            

        :param month: The month of this BillingCycleModel.
        :type: DisplayableMonth
        """

        self._month = month
    
    @property
    def number_of_periods(self):
        """Gets the number_of_periods of this BillingCycleModel.

            Billing Cycle type multiplied by Number of Periods defines billing cycle duration, e.g. 3 months. Monthly types require 1-12; weekly and yearly types require 1-9 periods; and daily types require 1-30.

        :return: The number_of_periods of this BillingCycleModel.
        :rtype: int
        """
        return self._number_of_periods

    @number_of_periods.setter
    def number_of_periods(self, number_of_periods):
        """Sets the number_of_periods of this BillingCycleModel.

            Billing Cycle type multiplied by Number of Periods defines billing cycle duration, e.g. 3 months. Monthly types require 1-12; weekly and yearly types require 1-9 periods; and daily types require 1-30.

        :param number_of_periods: The number_of_periods of this BillingCycleModel.
        :type: int
        """
        if number_of_periods is None:
            raise ValueError("Invalid value for `number_of_periods`, must not be `None`")

        self._number_of_periods = number_of_periods
    
    @property
    def weekly_day(self):
        """Gets the weekly_day of this BillingCycleModel.

            

        :return: The weekly_day of this BillingCycleModel.
        :rtype: DisplayableDayOfWeek
        """
        return self._weekly_day

    @weekly_day.setter
    def weekly_day(self, weekly_day):
        """Sets the weekly_day of this BillingCycleModel.

            

        :param weekly_day: The weekly_day of this BillingCycleModel.
        :type: DisplayableDayOfWeek
        """

        self._weekly_day = weekly_day
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(BillingCycleModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, BillingCycleModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PersistableCurrencyAmount:

    swagger_types = {
    
        'amount': 'float',
        'currency': 'str',
    }

    attribute_map = {
        'amount': 'amount','currency': 'currency',
    }

    
    _amount = None
    _currency = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.amount = kwargs.get('amount', None)
        self.currency = kwargs.get('currency', None)
        

    
    @property
    def amount(self):
        """Gets the amount of this PersistableCurrencyAmount.

            

        :return: The amount of this PersistableCurrencyAmount.
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this PersistableCurrencyAmount.

            

        :param amount: The amount of this PersistableCurrencyAmount.
        :type: float
        """

        self._amount = amount
    
    @property
    def currency(self):
        """Gets the currency of this PersistableCurrencyAmount.

            

        :return: The currency of this PersistableCurrencyAmount.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this PersistableCurrencyAmount.

            

        :param currency: The currency of this PersistableCurrencyAmount.
        :type: str
        """

        self._currency = currency
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PersistableCurrencyAmount, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PersistableCurrencyAmount):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class ProductSetupFeeUpdate:

    swagger_types = {
    
        'id': 'int',
        'version': 'int',
        'component': 'int',
        'description': 'dict(str, str)',
        'name': 'dict(str, str)',
        'on_downgrade_credited_amount': 'list[PersistableCurrencyAmountUpdate]',
        'on_upgrade_credited_amount': 'list[PersistableCurrencyAmountUpdate]',
        'setup_fee': 'list[PersistableCurrencyAmountUpdate]',
    }

    attribute_map = {
        'id': 'id','version': 'version','component': 'component','description': 'description','name': 'name','on_downgrade_credited_amount': 'onDowngradeCreditedAmount','on_upgrade_credited_amount': 'onUpgradeCreditedAmount','setup_fee': 'setupFee',
    }

    
    _id = None
    _version = None
    _component = None
    _description = None
    _name = None
    _on_downgrade_credited_amount = None
    _on_upgrade_credited_amount = None
    _setup_fee = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.id = kwargs.get('id')

        self.version = kwargs.get('version')

        self.component = kwargs.get('component', None)
        self.description = kwargs.get('description', None)
        self.name = kwargs.get('name', None)
        self.on_downgrade_credited_amount = kwargs.get('on_downgrade_credited_amount', None)
        self.on_upgrade_credited_amount = kwargs.get('on_upgrade_credited_amount', None)
        self.setup_fee = kwargs.get('setup_fee', None)
        

    
    @property
    def id(self):
        """Gets the id of this ProductSetupFeeUpdate.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this ProductSetupFeeUpdate.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProductSetupFeeUpdate.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this ProductSetupFeeUpdate.
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id
    
    @property
    def version(self):
        """Gets the version of this ProductSetupFeeUpdate.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this ProductSetupFeeUpdate.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ProductSetupFeeUpdate.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this ProductSetupFeeUpdate.
        :type: int
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")

        self._version = version
    
    @property
    def component(self):
        """Gets the component of this ProductSetupFeeUpdate.

            The product component that the fee belongs to.

        :return: The component of this ProductSetupFeeUpdate.
        :rtype: int
        """
        return self._component

    @component.setter
    def component(self, component):
        """Sets the component of this ProductSetupFeeUpdate.

            The product component that the fee belongs to.

        :param component: The component of this ProductSetupFeeUpdate.
        :type: int
        """

        self._component = component
    
    @property
    def description(self):
        """Gets the description of this ProductSetupFeeUpdate.

            The localized description of the fee that is displayed to the customer.

        :return: The description of this ProductSetupFeeUpdate.
        :rtype: dict(str, str)
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ProductSetupFeeUpdate.

            The localized description of the fee that is displayed to the customer.

        :param description: The description of this ProductSetupFeeUpdate.
        :type: dict(str, str)
        """

        self._description = description
    
    @property
    def name(self):
        """Gets the name of this ProductSetupFeeUpdate.

            The localized name of the fee that is displayed to the customer.

        :return: The name of this ProductSetupFeeUpdate.
        :rtype: dict(str, str)
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProductSetupFeeUpdate.

            The localized name of the fee that is displayed to the customer.

        :param name: The name of this ProductSetupFeeUpdate.
        :type: dict(str, str)
        """

        self._name = name
    
    @property
    def on_downgrade_credited_amount(self):
        """Gets the on_downgrade_credited_amount of this ProductSetupFeeUpdate.

            The amount charged to the customer when a subscription is downgraded.

        :return: The on_downgrade_credited_amount of this ProductSetupFeeUpdate.
        :rtype: list[PersistableCurrencyAmountUpdate]
        """
        return self._on_downgrade_credited_amount

    @on_downgrade_credited_amount.setter
    def on_downgrade_credited_amount(self, on_downgrade_credited_amount):
        """Sets the on_downgrade_credited_amount of this ProductSetupFeeUpdate.

            The amount charged to the customer when a subscription is downgraded.

        :param on_downgrade_credited_amount: The on_downgrade_credited_amount of this ProductSetupFeeUpdate.
        :type: list[PersistableCurrencyAmountUpdate]
        """

        self._on_downgrade_credited_amount = on_downgrade_credited_amount
    
    @property
    def on_upgrade_credited_amount(self):
        """Gets the on_upgrade_credited_amount of this ProductSetupFeeUpdate.

            The amount charged to the customer when a subscription is upgraded.

        :return: The on_upgrade_credited_amount of this ProductSetupFeeUpdate.
        :rtype: list[PersistableCurrencyAmountUpdate]
        """
        return self._on_upgrade_credited_amount

    @on_upgrade_credited_amount.setter
    def on_upgrade_credited_amount(self, on_upgrade_credited_amount):
        """Sets the on_upgrade_credited_amount of this ProductSetupFeeUpdate.

            The amount charged to the customer when a subscription is upgraded.

        :param on_upgrade_credited_amount: The on_upgrade_credited_amount of this ProductSetupFeeUpdate.
        :type: list[PersistableCurrencyAmountUpdate]
        """

        self._on_upgrade_credited_amount = on_upgrade_credited_amount
    
    @property
    def setup_fee(self):
        """Gets the setup_fee of this ProductSetupFeeUpdate.

            The amount charged to the customer once when they subscribe to a subscription.

        :return: The setup_fee of this ProductSetupFeeUpdate.
        :rtype: list[PersistableCurrencyAmountUpdate]
        """
        return self._setup_fee

    @setup_fee.setter
    def setup_fee(self, setup_fee):
        """Sets the setup_fee of this ProductSetupFeeUpdate.

            The amount charged to the customer once when they subscribe to a subscription.

        :param setup_fee: The setup_fee of this ProductSetupFeeUpdate.
        :type: list[PersistableCurrencyAmountUpdate]
        """

        self._setup_fee = setup_fee
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ProductSetupFeeUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ProductSetupFeeUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionSuspension:

    swagger_types = {
    
        'created_on': 'datetime',
        'effective_end_date': 'datetime',
        'end_action': 'SubscriptionSuspensionAction',
        'id': 'int',
        'language': 'str',
        'linked_space_id': 'int',
        'note': 'str',
        'period_bill': 'int',
        'planned_end_date': 'datetime',
        'planned_purge_date': 'datetime',
        'reason': 'SubscriptionSuspensionReason',
        'state': 'SubscriptionSuspensionState',
        'subscription': 'int',
        'version': 'int',
    }

    attribute_map = {
        'created_on': 'createdOn','effective_end_date': 'effectiveEndDate','end_action': 'endAction','id': 'id','language': 'language','linked_space_id': 'linkedSpaceId','note': 'note','period_bill': 'periodBill','planned_end_date': 'plannedEndDate','planned_purge_date': 'plannedPurgeDate','reason': 'reason','state': 'state','subscription': 'subscription','version': 'version',
    }

    
    _created_on = None
    _effective_end_date = None
    _end_action = None
    _id = None
    _language = None
    _linked_space_id = None
    _note = None
    _period_bill = None
    _planned_end_date = None
    _planned_purge_date = None
    _reason = None
    _state = None
    _subscription = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.created_on = kwargs.get('created_on', None)
        self.effective_end_date = kwargs.get('effective_end_date', None)
        self.end_action = kwargs.get('end_action', None)
        self.id = kwargs.get('id', None)
        self.language = kwargs.get('language', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.note = kwargs.get('note', None)
        self.period_bill = kwargs.get('period_bill', None)
        self.planned_end_date = kwargs.get('planned_end_date', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.reason = kwargs.get('reason', None)
        self.state = kwargs.get('state', None)
        self.subscription = kwargs.get('subscription', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def created_on(self):
        """Gets the created_on of this SubscriptionSuspension.

            The date and time when the object was created.

        :return: The created_on of this SubscriptionSuspension.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this SubscriptionSuspension.

            The date and time when the object was created.

        :param created_on: The created_on of this SubscriptionSuspension.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def effective_end_date(self):
        """Gets the effective_end_date of this SubscriptionSuspension.

            The date and time when the suspension ended.

        :return: The effective_end_date of this SubscriptionSuspension.
        :rtype: datetime
        """
        return self._effective_end_date

    @effective_end_date.setter
    def effective_end_date(self, effective_end_date):
        """Sets the effective_end_date of this SubscriptionSuspension.

            The date and time when the suspension ended.

        :param effective_end_date: The effective_end_date of this SubscriptionSuspension.
        :type: datetime
        """

        self._effective_end_date = effective_end_date
    
    @property
    def end_action(self):
        """Gets the end_action of this SubscriptionSuspension.

            Whether the subscription should be terminated or reactivated after the suspension has reached its end date.

        :return: The end_action of this SubscriptionSuspension.
        :rtype: SubscriptionSuspensionAction
        """
        return self._end_action

    @end_action.setter
    def end_action(self, end_action):
        """Sets the end_action of this SubscriptionSuspension.

            Whether the subscription should be terminated or reactivated after the suspension has reached its end date.

        :param end_action: The end_action of this SubscriptionSuspension.
        :type: SubscriptionSuspensionAction
        """

        self._end_action = end_action
    
    @property
    def id(self):
        """Gets the id of this SubscriptionSuspension.

            A unique identifier for the object.

        :return: The id of this SubscriptionSuspension.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionSuspension.

            A unique identifier for the object.

        :param id: The id of this SubscriptionSuspension.
        :type: int
        """

        self._id = id
    
    @property
    def language(self):
        """Gets the language of this SubscriptionSuspension.

            The language that is linked to the object.

        :return: The language of this SubscriptionSuspension.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this SubscriptionSuspension.

            The language that is linked to the object.

        :param language: The language of this SubscriptionSuspension.
        :type: str
        """

        self._language = language
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this SubscriptionSuspension.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this SubscriptionSuspension.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this SubscriptionSuspension.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this SubscriptionSuspension.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def note(self):
        """Gets the note of this SubscriptionSuspension.

            A note that contains details about the suspension. It is not disclosed to the subscriber.

        :return: The note of this SubscriptionSuspension.
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this SubscriptionSuspension.

            A note that contains details about the suspension. It is not disclosed to the subscriber.

        :param note: The note of this SubscriptionSuspension.
        :type: str
        """
        if note is not None and len(note) > 300:
            raise ValueError("Invalid value for `note`, length must be less than or equal to `300`")

        self._note = note
    
    @property
    def period_bill(self):
        """Gets the period_bill of this SubscriptionSuspension.

            The period bill that led to the suspension of the subscription.

        :return: The period_bill of this SubscriptionSuspension.
        :rtype: int
        """
        return self._period_bill

    @period_bill.setter
    def period_bill(self, period_bill):
        """Sets the period_bill of this SubscriptionSuspension.

            The period bill that led to the suspension of the subscription.

        :param period_bill: The period_bill of this SubscriptionSuspension.
        :type: int
        """

        self._period_bill = period_bill
    
    @property
    def planned_end_date(self):
        """Gets the planned_end_date of this SubscriptionSuspension.

            The date and time when the suspension is planned to end.

        :return: The planned_end_date of this SubscriptionSuspension.
        :rtype: datetime
        """
        return self._planned_end_date

    @planned_end_date.setter
    def planned_end_date(self, planned_end_date):
        """Sets the planned_end_date of this SubscriptionSuspension.

            The date and time when the suspension is planned to end.

        :param planned_end_date: The planned_end_date of this SubscriptionSuspension.
        :type: datetime
        """

        self._planned_end_date = planned_end_date
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this SubscriptionSuspension.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this SubscriptionSuspension.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this SubscriptionSuspension.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this SubscriptionSuspension.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def reason(self):
        """Gets the reason of this SubscriptionSuspension.

            The reason why the subscription was suspended.

        :return: The reason of this SubscriptionSuspension.
        :rtype: SubscriptionSuspensionReason
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this SubscriptionSuspension.

            The reason why the subscription was suspended.

        :param reason: The reason of this SubscriptionSuspension.
        :type: SubscriptionSuspensionReason
        """

        self._reason = reason
    
    @property
    def state(self):
        """Gets the state of this SubscriptionSuspension.

            The object's current state.

        :return: The state of this SubscriptionSuspension.
        :rtype: SubscriptionSuspensionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this SubscriptionSuspension.

            The object's current state.

        :param state: The state of this SubscriptionSuspension.
        :type: SubscriptionSuspensionState
        """

        self._state = state
    
    @property
    def subscription(self):
        """Gets the subscription of this SubscriptionSuspension.

            The subscription that this suspension belongs to.

        :return: The subscription of this SubscriptionSuspension.
        :rtype: int
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """Sets the subscription of this SubscriptionSuspension.

            The subscription that this suspension belongs to.

        :param subscription: The subscription of this SubscriptionSuspension.
        :type: int
        """

        self._subscription = subscription
    
    @property
    def version(self):
        """Gets the version of this SubscriptionSuspension.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this SubscriptionSuspension.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SubscriptionSuspension.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this SubscriptionSuspension.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionSuspension, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionSuspension):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractPaymentLinkUpdate:

    swagger_types = {
    
        'allowed_payment_method_configurations': 'list[PaymentMethodConfiguration]',
        'allowed_redirection_domains': 'list[str]',
        'applied_space_view': 'int',
        'available_from': 'datetime',
        'available_until': 'datetime',
        'billing_address_handling_mode': 'PaymentLinkAddressHandlingMode',
        'currency': 'str',
        'language': 'str',
        'line_items': 'list[LineItemCreate]',
        'maximal_number_of_transactions': 'int',
        'name': 'str',
        'shipping_address_handling_mode': 'PaymentLinkAddressHandlingMode',
    }

    attribute_map = {
        'allowed_payment_method_configurations': 'allowedPaymentMethodConfigurations','allowed_redirection_domains': 'allowedRedirectionDomains','applied_space_view': 'appliedSpaceView','available_from': 'availableFrom','available_until': 'availableUntil','billing_address_handling_mode': 'billingAddressHandlingMode','currency': 'currency','language': 'language','line_items': 'lineItems','maximal_number_of_transactions': 'maximalNumberOfTransactions','name': 'name','shipping_address_handling_mode': 'shippingAddressHandlingMode',
    }

    
    _allowed_payment_method_configurations = None
    _allowed_redirection_domains = None
    _applied_space_view = None
    _available_from = None
    _available_until = None
    _billing_address_handling_mode = None
    _currency = None
    _language = None
    _line_items = None
    _maximal_number_of_transactions = None
    _name = None
    _shipping_address_handling_mode = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.allowed_payment_method_configurations = kwargs.get('allowed_payment_method_configurations', None)
        self.allowed_redirection_domains = kwargs.get('allowed_redirection_domains', None)
        self.applied_space_view = kwargs.get('applied_space_view', None)
        self.available_from = kwargs.get('available_from', None)
        self.available_until = kwargs.get('available_until', None)
        self.billing_address_handling_mode = kwargs.get('billing_address_handling_mode', None)
        self.currency = kwargs.get('currency', None)
        self.language = kwargs.get('language', None)
        self.line_items = kwargs.get('line_items', None)
        self.maximal_number_of_transactions = kwargs.get('maximal_number_of_transactions', None)
        self.name = kwargs.get('name', None)
        self.shipping_address_handling_mode = kwargs.get('shipping_address_handling_mode', None)
        

    
    @property
    def allowed_payment_method_configurations(self):
        """Gets the allowed_payment_method_configurations of this AbstractPaymentLinkUpdate.

            The payment method configurations that customers can use for making payments.

        :return: The allowed_payment_method_configurations of this AbstractPaymentLinkUpdate.
        :rtype: list[PaymentMethodConfiguration]
        """
        return self._allowed_payment_method_configurations

    @allowed_payment_method_configurations.setter
    def allowed_payment_method_configurations(self, allowed_payment_method_configurations):
        """Sets the allowed_payment_method_configurations of this AbstractPaymentLinkUpdate.

            The payment method configurations that customers can use for making payments.

        :param allowed_payment_method_configurations: The allowed_payment_method_configurations of this AbstractPaymentLinkUpdate.
        :type: list[PaymentMethodConfiguration]
        """

        self._allowed_payment_method_configurations = allowed_payment_method_configurations
    
    @property
    def allowed_redirection_domains(self):
        """Gets the allowed_redirection_domains of this AbstractPaymentLinkUpdate.

            The domains to which the user is allowed to be redirected after the payment is completed. The following options can be configured: Exact domain: enter a full domain, e.g. (https://example.com). Wildcard domain: use to allow subdomains, e.g. (https://*.example.com). All domains: use (ALL) to allow redirection to any domain (not recommended for security reasons). No domains : use (NONE) to disallow any redirection. Only one option per line is allowed. Invalid entries will be rejected. 

        :return: The allowed_redirection_domains of this AbstractPaymentLinkUpdate.
        :rtype: list[str]
        """
        return self._allowed_redirection_domains

    @allowed_redirection_domains.setter
    def allowed_redirection_domains(self, allowed_redirection_domains):
        """Sets the allowed_redirection_domains of this AbstractPaymentLinkUpdate.

            The domains to which the user is allowed to be redirected after the payment is completed. The following options can be configured: Exact domain: enter a full domain, e.g. (https://example.com). Wildcard domain: use to allow subdomains, e.g. (https://*.example.com). All domains: use (ALL) to allow redirection to any domain (not recommended for security reasons). No domains : use (NONE) to disallow any redirection. Only one option per line is allowed. Invalid entries will be rejected. 

        :param allowed_redirection_domains: The allowed_redirection_domains of this AbstractPaymentLinkUpdate.
        :type: list[str]
        """

        self._allowed_redirection_domains = allowed_redirection_domains
    
    @property
    def applied_space_view(self):
        """Gets the applied_space_view of this AbstractPaymentLinkUpdate.

            The payment link can be used within a specific space view, which may apply a customized design to the payment page.

        :return: The applied_space_view of this AbstractPaymentLinkUpdate.
        :rtype: int
        """
        return self._applied_space_view

    @applied_space_view.setter
    def applied_space_view(self, applied_space_view):
        """Sets the applied_space_view of this AbstractPaymentLinkUpdate.

            The payment link can be used within a specific space view, which may apply a customized design to the payment page.

        :param applied_space_view: The applied_space_view of this AbstractPaymentLinkUpdate.
        :type: int
        """

        self._applied_space_view = applied_space_view
    
    @property
    def available_from(self):
        """Gets the available_from of this AbstractPaymentLinkUpdate.

            The earliest date the payment link can be used to initiate a transaction. If no date is provided, the link will be available immediately.

        :return: The available_from of this AbstractPaymentLinkUpdate.
        :rtype: datetime
        """
        return self._available_from

    @available_from.setter
    def available_from(self, available_from):
        """Sets the available_from of this AbstractPaymentLinkUpdate.

            The earliest date the payment link can be used to initiate a transaction. If no date is provided, the link will be available immediately.

        :param available_from: The available_from of this AbstractPaymentLinkUpdate.
        :type: datetime
        """

        self._available_from = available_from
    
    @property
    def available_until(self):
        """Gets the available_until of this AbstractPaymentLinkUpdate.

            The latest date the payment link can be used to initiate a transaction. If no date is provided, the link will remain available indefinitely.

        :return: The available_until of this AbstractPaymentLinkUpdate.
        :rtype: datetime
        """
        return self._available_until

    @available_until.setter
    def available_until(self, available_until):
        """Sets the available_until of this AbstractPaymentLinkUpdate.

            The latest date the payment link can be used to initiate a transaction. If no date is provided, the link will remain available indefinitely.

        :param available_until: The available_until of this AbstractPaymentLinkUpdate.
        :type: datetime
        """

        self._available_until = available_until
    
    @property
    def billing_address_handling_mode(self):
        """Gets the billing_address_handling_mode of this AbstractPaymentLinkUpdate.

            The handling mode defines whether a billing address is required and specifies how it should be provided.

        :return: The billing_address_handling_mode of this AbstractPaymentLinkUpdate.
        :rtype: PaymentLinkAddressHandlingMode
        """
        return self._billing_address_handling_mode

    @billing_address_handling_mode.setter
    def billing_address_handling_mode(self, billing_address_handling_mode):
        """Sets the billing_address_handling_mode of this AbstractPaymentLinkUpdate.

            The handling mode defines whether a billing address is required and specifies how it should be provided.

        :param billing_address_handling_mode: The billing_address_handling_mode of this AbstractPaymentLinkUpdate.
        :type: PaymentLinkAddressHandlingMode
        """

        self._billing_address_handling_mode = billing_address_handling_mode
    
    @property
    def currency(self):
        """Gets the currency of this AbstractPaymentLinkUpdate.

            The three-letter currency code (ISO 4217). If not specified, it must be provided in the 'currency' request parameter.

        :return: The currency of this AbstractPaymentLinkUpdate.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this AbstractPaymentLinkUpdate.

            The three-letter currency code (ISO 4217). If not specified, it must be provided in the 'currency' request parameter.

        :param currency: The currency of this AbstractPaymentLinkUpdate.
        :type: str
        """

        self._currency = currency
    
    @property
    def language(self):
        """Gets the language of this AbstractPaymentLinkUpdate.

            The language for displaying the payment page. If not specified, it can be supplied via the 'language' request parameter.

        :return: The language of this AbstractPaymentLinkUpdate.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this AbstractPaymentLinkUpdate.

            The language for displaying the payment page. If not specified, it can be supplied via the 'language' request parameter.

        :param language: The language of this AbstractPaymentLinkUpdate.
        :type: str
        """

        self._language = language
    
    @property
    def line_items(self):
        """Gets the line_items of this AbstractPaymentLinkUpdate.

            The line items representing what is being sold. If not specified, they can be supplied via request parameters.

        :return: The line_items of this AbstractPaymentLinkUpdate.
        :rtype: list[LineItemCreate]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this AbstractPaymentLinkUpdate.

            The line items representing what is being sold. If not specified, they can be supplied via request parameters.

        :param line_items: The line_items of this AbstractPaymentLinkUpdate.
        :type: list[LineItemCreate]
        """

        self._line_items = line_items
    
    @property
    def maximal_number_of_transactions(self):
        """Gets the maximal_number_of_transactions of this AbstractPaymentLinkUpdate.

            The maximum number of transactions that can be initiated using the payment link.

        :return: The maximal_number_of_transactions of this AbstractPaymentLinkUpdate.
        :rtype: int
        """
        return self._maximal_number_of_transactions

    @maximal_number_of_transactions.setter
    def maximal_number_of_transactions(self, maximal_number_of_transactions):
        """Sets the maximal_number_of_transactions of this AbstractPaymentLinkUpdate.

            The maximum number of transactions that can be initiated using the payment link.

        :param maximal_number_of_transactions: The maximal_number_of_transactions of this AbstractPaymentLinkUpdate.
        :type: int
        """

        self._maximal_number_of_transactions = maximal_number_of_transactions
    
    @property
    def name(self):
        """Gets the name of this AbstractPaymentLinkUpdate.

            The name used to identify the payment link.

        :return: The name of this AbstractPaymentLinkUpdate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AbstractPaymentLinkUpdate.

            The name used to identify the payment link.

        :param name: The name of this AbstractPaymentLinkUpdate.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def shipping_address_handling_mode(self):
        """Gets the shipping_address_handling_mode of this AbstractPaymentLinkUpdate.

            The handling mode defines whether a shipping address is required and specifies how it should be provided.

        :return: The shipping_address_handling_mode of this AbstractPaymentLinkUpdate.
        :rtype: PaymentLinkAddressHandlingMode
        """
        return self._shipping_address_handling_mode

    @shipping_address_handling_mode.setter
    def shipping_address_handling_mode(self, shipping_address_handling_mode):
        """Sets the shipping_address_handling_mode of this AbstractPaymentLinkUpdate.

            The handling mode defines whether a shipping address is required and specifies how it should be provided.

        :param shipping_address_handling_mode: The shipping_address_handling_mode of this AbstractPaymentLinkUpdate.
        :type: PaymentLinkAddressHandlingMode
        """

        self._shipping_address_handling_mode = shipping_address_handling_mode
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractPaymentLinkUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractPaymentLinkUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractSubscriptionAffiliateUpdate:

    swagger_types = {
    
        'language': 'str',
        'meta_data': 'dict(str, str)',
        'name': 'str',
        'state': 'CreationEntityState',
    }

    attribute_map = {
        'language': 'language','meta_data': 'metaData','name': 'name','state': 'state',
    }

    
    _language = None
    _meta_data = None
    _name = None
    _state = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.language = kwargs.get('language', None)
        self.meta_data = kwargs.get('meta_data', None)
        self.name = kwargs.get('name', None)
        self.state = kwargs.get('state', None)
        

    
    @property
    def language(self):
        """Gets the language of this AbstractSubscriptionAffiliateUpdate.

            The language that is linked to the object.

        :return: The language of this AbstractSubscriptionAffiliateUpdate.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this AbstractSubscriptionAffiliateUpdate.

            The language that is linked to the object.

        :param language: The language of this AbstractSubscriptionAffiliateUpdate.
        :type: str
        """

        self._language = language
    
    @property
    def meta_data(self):
        """Gets the meta_data of this AbstractSubscriptionAffiliateUpdate.

            Allow to store additional information about the object.

        :return: The meta_data of this AbstractSubscriptionAffiliateUpdate.
        :rtype: dict(str, str)
        """
        return self._meta_data

    @meta_data.setter
    def meta_data(self, meta_data):
        """Sets the meta_data of this AbstractSubscriptionAffiliateUpdate.

            Allow to store additional information about the object.

        :param meta_data: The meta_data of this AbstractSubscriptionAffiliateUpdate.
        :type: dict(str, str)
        """

        self._meta_data = meta_data
    
    @property
    def name(self):
        """Gets the name of this AbstractSubscriptionAffiliateUpdate.

            The name used to identify the affiliate.

        :return: The name of this AbstractSubscriptionAffiliateUpdate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AbstractSubscriptionAffiliateUpdate.

            The name used to identify the affiliate.

        :param name: The name of this AbstractSubscriptionAffiliateUpdate.
        :type: str
        """
        if name is not None and len(name) > 255:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")
        if name is not None and len(name) < 3:
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `3`")

        self._name = name
    
    @property
    def state(self):
        """Gets the state of this AbstractSubscriptionAffiliateUpdate.

            The object's current state.

        :return: The state of this AbstractSubscriptionAffiliateUpdate.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this AbstractSubscriptionAffiliateUpdate.

            The object's current state.

        :param state: The state of this AbstractSubscriptionAffiliateUpdate.
        :type: CreationEntityState
        """

        self._state = state
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractSubscriptionAffiliateUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractSubscriptionAffiliateUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
